@@ -19,13 +19,16 @@ package gce
 import (
 	"fmt"
 
+	"google.golang.org/api/cloudresourcemanager/v1"
 	compute "google.golang.org/api/compute/v1"
-	"google.golang.org/api/iam/v1"
 	"google.golang.org/api/storage/v1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/klog/v2"
+	"k8s.io/kops/cloudmock/gce/mockcloudresourcemanager"
 	mockcompute "k8s.io/kops/cloudmock/gce/mockcompute"
 	"k8s.io/kops/cloudmock/gce/mockdns"
+	"k8s.io/kops/cloudmock/gce/mockiam"
+	"k8s.io/kops/cloudmock/gce/mockstorage"
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider"
 	dnsproviderclouddns "k8s.io/kops/dnsprovider/pkg/dnsprovider/providers/google/clouddns"
 	"k8s.io/kops/pkg/apis/kops"
@@ -40,8 +43,11 @@ type MockGCECloud struct {
 	region  string
 	labels  map[string]string
 
-	computeClient *mockcompute.MockClient
-	dnsClient     *mockdns.MockClient
+	computeClient              *mockcompute.MockClient
+	dnsClient                  *mockdns.MockClient
+	iamClient                  *mockiam.MockClient
+	storageClient              *storage.Service
+	cloudResourceManagerClient *cloudresourcemanager.Service
 }
 
 var _ gce.GCECloud = &MockGCECloud{}
@@ -49,10 +55,13 @@ var _ gce.GCECloud = &MockGCECloud{}
 // InstallMockGCECloud registers a MockGCECloud implementation for the specified region & project
 func InstallMockGCECloud(region string, project string) *MockGCECloud {
 	c := &MockGCECloud{
-		project:       project,
-		region:        region,
-		computeClient: mockcompute.NewMockClient(project),
-		dnsClient:     mockdns.NewMockClient(),
+		project:                    project,
+		region:                     region,
+		computeClient:              mockcompute.NewMockClient(project),
+		dnsClient:                  mockdns.NewMockClient(),
+		iamClient:                  mockiam.NewMockClient(project),
+		storageClient:              mockstorage.New(),
+		cloudResourceManagerClient: mockcloudresourcemanager.New(),
 	}
 	gce.CacheGCECloudInstance(region, project, c)
 	return c
@@ -103,14 +112,17 @@ func (c *MockGCECloud) Compute() gce.ComputeClient {
 
 // Storage implements GCECloud::Storage
 func (c *MockGCECloud) Storage() *storage.Service {
-	klog.Fatalf("MockGCECloud::Storage not implemented")
-	return nil
+	return c.storageClient
 }
 
 // IAM returns the IAM client
-func (c *MockGCECloud) IAM() *iam.Service {
-	klog.Fatalf("MockGCECloud::IAM not implemented")
-	return nil
+func (c *MockGCECloud) IAM() gce.IamClient {
+	return c.iamClient
+}
+
+// CloudResourceManager returns the client for the cloudresourcemanager API
+func (c *MockGCECloud) CloudResourceManager() *cloudresourcemanager.Service {
+	return c.cloudResourceManagerClient
 }
 
 // CloudDNS returns the DNS client
@@ -168,6 +180,10 @@ func (c *MockGCECloud) DeleteInstance(i *cloudinstances.CloudInstance) error {
 	//	return recreateCloudInstance(c, i)
 }
 
+func (c *MockGCECloud) DeregisterInstance(i *cloudinstances.CloudInstance) error {
+	return nil
+}
+
 // DetachInstance is not implemented yet. It needs to cause a cloud instance to no longer be counted against the group's size limits.
 func (c *MockGCECloud) DetachInstance(i *cloudinstances.CloudInstance) error {
 	return nil
