@@ -45,9 +45,15 @@ func ValidateInstanceGroup(g *kops.InstanceGroup, cloud fi.Cloud, strict bool) f
 	switch g.Spec.Role {
 	case "":
 		allErrs = append(allErrs, field.Required(field.NewPath("spec", "role"), "Role must be set"))
-	case kops.InstanceGroupRoleMaster:
+	case kops.InstanceGroupRoleControlPlane:
 		if len(g.Spec.Subnets) == 0 {
-			allErrs = append(allErrs, field.Required(field.NewPath("spec", "subnets"), "master InstanceGroup must specify at least one Subnet"))
+			allErrs = append(allErrs, field.Required(field.NewPath("spec", "subnets"), "controlPlane InstanceGroup must specify at least one Subnet"))
+		}
+		if fi.ValueOf(g.Spec.MinSize) > 1 {
+			allErrs = append(allErrs, field.Invalid(field.NewPath("spec", "minSize"), fi.ValueOf(g.Spec.MinSize), "controlPlane InstanceGroup must have minSize set to 1"))
+		}
+		if fi.ValueOf(g.Spec.MaxSize) > 1 {
+			allErrs = append(allErrs, field.Invalid(field.NewPath("spec", "maxSize"), fi.ValueOf(g.Spec.MaxSize), "controlPlane InstanceGroup must have maxSize set to 1, add more InstanceGroups instead"))
 		}
 	case kops.InstanceGroupRoleNode:
 	case kops.InstanceGroupRoleBastion:
@@ -83,11 +89,11 @@ func ValidateInstanceGroup(g *kops.InstanceGroup, cloud fi.Cloud, strict bool) f
 		allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "image"), "image must be specified."))
 	}
 
-	if fi.Int32Value(g.Spec.RootVolumeIOPS) < 0 {
-		allErrs = append(allErrs, field.Invalid(field.NewPath("spec", "rootVolumeIops"), g.Spec.RootVolumeIOPS, "RootVolumeIOPS must be greater than 0"))
+	if fi.ValueOf(g.Spec.RootVolumeIOPS) < 0 {
+		allErrs = append(allErrs, field.Invalid(field.NewPath("spec", "rootVolumeIOPS"), g.Spec.RootVolumeIOPS, "RootVolumeIOPS must be greater than 0"))
 	}
 
-	if fi.Int32Value(g.Spec.RootVolumeThroughput) < 0 {
+	if fi.ValueOf(g.Spec.RootVolumeThroughput) < 0 {
 		allErrs = append(allErrs, field.Invalid(field.NewPath("spec", "rootVolumeThroughput"), g.Spec.RootVolumeThroughput, "RootVolumeThroughput must be greater than 0"))
 	}
 
@@ -137,7 +143,7 @@ func ValidateInstanceGroup(g *kops.InstanceGroup, cloud fi.Cloud, strict bool) f
 	allErrs = append(allErrs, validateInstanceProfile(g.Spec.IAM, field.NewPath("spec", "iam"))...)
 
 	if g.Spec.RollingUpdate != nil {
-		allErrs = append(allErrs, validateRollingUpdate(g.Spec.RollingUpdate, field.NewPath("spec", "rollingUpdate"), g.Spec.Role == kops.InstanceGroupRoleMaster)...)
+		allErrs = append(allErrs, validateRollingUpdate(g.Spec.RollingUpdate, field.NewPath("spec", "rollingUpdate"), g.Spec.Role == kops.InstanceGroupRoleControlPlane)...)
 	}
 
 	if g.Spec.NodeLabels != nil {
@@ -219,25 +225,30 @@ func validateVolumeMountSpec(path *field.Path, spec kops.VolumeMountSpec) field.
 func CrossValidateInstanceGroup(g *kops.InstanceGroup, cluster *kops.Cluster, cloud fi.Cloud, strict bool) field.ErrorList {
 	allErrs := ValidateInstanceGroup(g, cloud, strict)
 
-	if g.Spec.Role == kops.InstanceGroupRoleMaster {
-		allErrs = append(allErrs, ValidateMasterInstanceGroup(g, cluster)...)
+	if g.Spec.Role == kops.InstanceGroupRoleControlPlane {
+		allErrs = append(allErrs, ValidateControlPlaneInstanceGroup(g, cluster)...)
 	}
 
-	if g.Spec.Role == kops.InstanceGroupRoleAPIServer && cluster.Spec.GetCloudProvider() != kops.CloudProviderAWS {
-		allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "role"), "Apiserver role only supported on AWS"))
+	if g.Spec.Role == kops.InstanceGroupRoleAPIServer {
+		if cluster.Spec.GetCloudProvider() != kops.CloudProviderAWS {
+			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "role"), "APIServer role only supported on AWS"))
+		}
+		if cluster.UsesNoneDNS() {
+			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "role"), "APIServer cannot be used with topology.dns.type=None"))
+		}
 	}
 
 	// Check that instance groups are defined in subnets that are defined in the cluster
 	{
 		clusterSubnets := make(map[string]*kops.ClusterSubnetSpec)
-		for i := range cluster.Spec.Subnets {
-			s := &cluster.Spec.Subnets[i]
+		for i := range cluster.Spec.Networking.Subnets {
+			s := &cluster.Spec.Networking.Subnets[i]
 			clusterSubnets[s.Name] = s
 		}
 
 		for i, z := range g.Spec.Subnets {
 			if clusterSubnets[z] == nil {
-				allErrs = append(allErrs, field.NotFound(field.NewPath("spec", "subnets").Index(i), z))
+				allErrs = append(allErrs, field.NotFound(field.NewPath("spec", "networking", "subnets").Index(i), z))
 			}
 		}
 	}
@@ -246,18 +257,8 @@ func CrossValidateInstanceGroup(g *kops.InstanceGroup, cluster *kops.Cluster, cl
 		if g.Spec.RootVolumeType != nil {
 			allErrs = append(allErrs, IsValidValue(field.NewPath("spec", "rootVolumeType"), g.Spec.RootVolumeType, []string{"standard", "gp3", "gp2", "io1", "io2"})...)
 		}
-	} else {
-		if g.Spec.WarmPool != nil {
-			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "warmPool"), "warm pool only supported on AWS"))
-		}
-	}
 
-	if g.Spec.Containerd != nil {
-		allErrs = append(allErrs, validateContainerdConfig(&cluster.Spec, g.Spec.Containerd, field.NewPath("spec", "containerd"), false)...)
-	}
-
-	{
-		warmPool := cluster.Spec.WarmPool.ResolveDefaults(g)
+		warmPool := cluster.Spec.CloudProvider.AWS.WarmPool.ResolveDefaults(g)
 		if warmPool.MaxSize == nil || *warmPool.MaxSize != 0 {
 			if g.Spec.Role != kops.InstanceGroupRoleNode && g.Spec.Role != kops.InstanceGroupRoleAPIServer {
 				allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "warmPool"), "warm pool only allowed on instance groups with role Node or APIServer"))
@@ -281,21 +282,25 @@ func CrossValidateInstanceGroup(g *kops.InstanceGroup, cluster *kops.Cluster, cl
 		}
 	}
 
+	if g.Spec.Containerd != nil {
+		allErrs = append(allErrs, validateContainerdConfig(&cluster.Spec, g.Spec.Containerd, field.NewPath("spec", "containerd"), false)...)
+	}
+
 	return allErrs
 }
 
-func ValidateMasterInstanceGroup(g *kops.InstanceGroup, cluster *kops.Cluster) field.ErrorList {
+func ValidateControlPlaneInstanceGroup(g *kops.InstanceGroup, cluster *kops.Cluster) field.ErrorList {
 	allErrs := field.ErrorList{}
 	for _, etcd := range cluster.Spec.EtcdClusters {
 		hasEtcd := false
 		for _, m := range etcd.Members {
-			if fi.StringValue(m.InstanceGroup) == g.ObjectMeta.Name {
+			if fi.ValueOf(m.InstanceGroup) == g.ObjectMeta.Name {
 				hasEtcd = true
 				break
 			}
 		}
 		if !hasEtcd {
-			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "metadata", "name"), fmt.Sprintf("InstanceGroup \"%s\" with role Master must have a member in etcd cluster \"%s\"", g.ObjectMeta.Name, etcd.Name)))
+			allErrs = append(allErrs, field.Forbidden(field.NewPath("spec", "metadata", "name"), fmt.Sprintf("InstanceGroup \"%s\" with role ControlPlane must have a member in etcd cluster \"%s\"", g.ObjectMeta.Name, etcd.Name)))
 		}
 	}
 	return allErrs
@@ -376,7 +381,7 @@ func validateIGCloudLabels(ig *kops.InstanceGroup, fldPath *field.Path) (allErrs
 	return allErrs
 }
 
-func validateExternalLoadBalancer(lb *kops.LoadBalancer, fldPath *field.Path) field.ErrorList {
+func validateExternalLoadBalancer(lb *kops.LoadBalancerSpec, fldPath *field.Path) field.ErrorList {
 	allErrs := field.ErrorList{}
 
 	if lb.LoadBalancerName != nil && lb.TargetGroupARN != nil {
@@ -384,7 +389,7 @@ func validateExternalLoadBalancer(lb *kops.LoadBalancer, fldPath *field.Path) fi
 	}
 
 	if lb.LoadBalancerName != nil {
-		name := fi.StringValue(lb.LoadBalancerName)
+		name := fi.ValueOf(lb.LoadBalancerName)
 		if len(name) > 32 {
 			allErrs = append(allErrs, field.Invalid(fldPath.Child("loadBalancerName"), name,
 				"Load Balancer name must have at most 32 characters"))
@@ -392,31 +397,31 @@ func validateExternalLoadBalancer(lb *kops.LoadBalancer, fldPath *field.Path) fi
 	}
 
 	if lb.TargetGroupARN != nil {
-		actual := fi.StringValue(lb.TargetGroupARN)
+		actual := fi.ValueOf(lb.TargetGroupARN)
 
 		parsed, err := arn.Parse(actual)
 		if err != nil {
-			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupArn"), actual,
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupARN"), actual,
 				fmt.Sprintf("Target Group ARN must be a valid AWS ARN: %v", err)))
 			return allErrs
 		}
 
 		resource := strings.Split(parsed.Resource, "/")
 		if len(resource) != 3 {
-			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupArn"), actual,
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupARN"), actual,
 				"Target Group ARN resource must be a valid AWS ARN resource such as \"targetgroup/tg-name/1234567890123456\""))
 			return allErrs
 		}
 
 		kind := resource[0]
 		if kind != "targetgroup" {
-			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupArn"), kind,
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupARN"), kind,
 				"Target Group ARN resource type must be \"targetgroup\""))
 		}
 
 		name := resource[1]
 		if len(name) > 32 {
-			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupArn"), name,
+			allErrs = append(allErrs, field.Invalid(fldPath.Child("targetGroupARN"), name,
 				"Target Group ARN resource name must have at most 32 characters"))
 		}
 	}
