@@ -19,8 +19,8 @@ package nodeup
 import (
 	"strings"
 
+	"github.com/aws/aws-sdk-go/aws"
 	"k8s.io/kops/pkg/apis/kops"
-	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/util/pkg/architectures"
 )
 
@@ -85,11 +85,14 @@ type Config struct {
 // BootConfig is the configuration for the nodeup binary that might be too big to fit in userdata.
 type BootConfig struct {
 	// CloudProvider is the cloud provider in use.
-	CloudProvider string
+	CloudProvider kops.CloudProviderID
 	// ConfigBase is the base VFS path for config objects.
 	ConfigBase *string `json:",omitempty"`
 	// ConfigServer holds the configuration for the configuration server.
 	ConfigServer *ConfigServerOptions `json:",omitempty"`
+	// APIServerIPs is the API server IP addresses.
+	// This field is used for adding an alias for api.internal. in /etc/hosts, when Topology.DNS.Type == DNSTypeNone.
+	APIServerIPs []string `json:",omitempty"`
 	// InstanceGroupName is the name of the instance group.
 	InstanceGroupName string `json:",omitempty"`
 	// InstanceGroupRole is the instance group role.
@@ -99,8 +102,8 @@ type BootConfig struct {
 }
 
 type ConfigServerOptions struct {
-	// Server is the address of the configuration server to use (kops-controller)
-	Server string `json:"server,omitempty"`
+	// Servers are the addresses of the configuration servers to use (kops-controller)
+	Servers []string `json:"servers,omitempty"`
 	// CACertificates are the certificates to trust for fi.CertificateIDCA.
 	CACertificates string
 }
@@ -152,14 +155,16 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 	}
 
 	bootConfig := BootConfig{
-		CloudProvider:     string(cluster.Spec.GetCloudProvider()),
+		CloudProvider:     cluster.Spec.GetCloudProvider(),
 		InstanceGroupName: instanceGroup.ObjectMeta.Name,
 		InstanceGroupRole: role,
 	}
 
-	warmPool := cluster.Spec.WarmPool.ResolveDefaults(instanceGroup)
-	if warmPool.IsEnabled() && warmPool.EnableLifecycleHook {
-		config.EnableLifecycleHook = true
+	if cluster.Spec.CloudProvider.AWS != nil {
+		warmPool := cluster.Spec.CloudProvider.AWS.WarmPool.ResolveDefaults(instanceGroup)
+		if warmPool.IsEnabled() && warmPool.EnableLifecycleHook {
+			config.EnableLifecycleHook = true
+		}
 	}
 
 	if instanceGroup.Spec.UpdatePolicy != nil {
@@ -170,8 +175,8 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 		config.UpdatePolicy = kops.UpdatePolicyAutomatic
 	}
 
-	if cluster.Spec.Networking != nil && cluster.Spec.Networking.AmazonVPC != nil {
-		config.DefaultMachineType = fi.String(strings.Split(instanceGroup.Spec.MachineType, ",")[0])
+	if cluster.Spec.Networking.AmazonVPC != nil {
+		config.DefaultMachineType = aws.String(strings.Split(instanceGroup.Spec.MachineType, ",")[0])
 	}
 
 	if UsesInstanceIDForNodeName(cluster) {
