@@ -25,6 +25,7 @@ limitations under the License.
 package featureflag
 
 import (
+	"fmt"
 	"os"
 	"strings"
 	"sync"
@@ -68,8 +69,6 @@ var (
 	SpotinstHybrid = new("SpotinstHybrid", Bool(false))
 	// SpotinstController toggles the installation of the Spotinst controller addon.
 	SpotinstController = new("SpotinstController", Bool(true))
-	// VFSVaultSupport enables setting Vault as secret/keystore
-	VFSVaultSupport = new("VFSVaultSupport", Bool(false))
 	// VPCSkipEnableDNSSupport if set will make that a VPC does not need DNSSupport enabled.
 	VPCSkipEnableDNSSupport = new("VPCSkipEnableDNSSupport", Bool(false))
 	// SkipEtcdVersionCheck will bypass the check that etcd-manager is using a supported etcd version
@@ -78,8 +77,6 @@ var (
 	ClusterAddons = new("ClusterAddons", Bool(false))
 	// Azure toggles the Azure support.
 	Azure = new("Azure", Bool(false))
-	// KopsControllerStateStore enables fetching the kops state from kops-controller, instead of requiring access to S3/GCS/etc.
-	KopsControllerStateStore = new("KopsControllerStateStore", Bool(false))
 	// APIServerNodes enables ability to provision nodes that only run the kube-apiserver.
 	APIServerNodes = new("APIServerNodes", Bool(false))
 	// UseAddonOperators activates experimental addon operator support
@@ -90,6 +87,15 @@ var (
 	Karpenter = new("Karpenter", Bool(false))
 	// ImageDigest remaps all manifests with image digests
 	ImageDigest = new("ImageDigest", Bool(true))
+	// Scaleway toggles the Scaleway Cloud support.
+	Scaleway = new("Scaleway", Bool(false))
+	// SELinuxMount configures AWS EBS CSI driver for SELinuxMount support.
+	// It expects than Kubernetes feature gate SELinuxMountReadWriteOncePod is
+	// enabled or GA in the API server, KCM and kubelet.
+	// OS with SELinux support on all nodes is recommended, but not required
+	// - the feature won't do anything when the node OS does not support SELinux.
+	// TODO(jsafrane): add to all CSI drivers installed by kops.
+	SELinuxMount = new("SELinuxMount", Bool(false))
 )
 
 // FeatureFlag defines a feature flag
@@ -164,3 +170,15 @@ func ParseFlags(f string) {
 		}
 	}
 }
+
+// Get returns given FeatureFlag.
+func Get(flagName string) (*FeatureFlag, error) {
+	flagsMutex.Lock()
+	defer flagsMutex.Unlock()
+
+	flag, found := flags[flagName]
+	if !found {
+		return nil, fmt.Errorf("flag %s not found", flagName)
+	}
+	return flag, nil
+}
