@@ -38,7 +38,7 @@ import (
 	"k8s.io/kops/util/pkg/vfs"
 )
 
-func getTestSetupOS(t *testing.T) (*RollingUpdateCluster, *openstack.MockCloud) {
+func getTestSetupOS(t *testing.T, ctx context.Context) (*RollingUpdateCluster, *openstack.MockCloud) {
 	vfs.Context.ResetMemfsContext(true)
 
 	k8sClient := fake.NewSimpleClientset()
@@ -50,8 +50,8 @@ func getTestSetupOS(t *testing.T) (*RollingUpdateCluster, *openstack.MockCloud)
 	inCluster.Spec.CloudProvider.Openstack = &kopsapi.OpenstackSpec{}
 	inCluster.Name = "test.k8s.local"
 
-	inCluster.Spec.Topology.Masters = kopsapi.TopologyPrivate
-	inCluster.Spec.Topology.Nodes = kopsapi.TopologyPrivate
+	inCluster.Spec.Networking.Topology.ControlPlane = kopsapi.TopologyPrivate
+	inCluster.Spec.Networking.Topology.Nodes = kopsapi.TopologyPrivate
 
 	err := cloudup.PerformAssignments(inCluster, mockcloud)
 	if err != nil {
@@ -61,7 +61,7 @@ func getTestSetupOS(t *testing.T) (*RollingUpdateCluster, *openstack.MockCloud)
 	assetBuilder := assets.NewAssetBuilder(inCluster, false)
 	basePath, _ := vfs.Context.BuildVfsPath(inCluster.Spec.ConfigBase)
 	clientset := vfsclientset.NewVFSClientset(basePath)
-	cluster, err := cloudup.PopulateClusterSpec(clientset, inCluster, mockcloud, assetBuilder)
+	cluster, err := cloudup.PopulateClusterSpec(ctx, clientset, inCluster, mockcloud, assetBuilder)
 	if err != nil {
 		t.Fatalf("Failed to populate cluster spec: %v", err)
 	}
@@ -72,7 +72,7 @@ func getTestSetupOS(t *testing.T) (*RollingUpdateCluster, *openstack.MockCloud)
 		t.Fatalf("Failed to get credential store: %v", err)
 	}
 
-	sshCredentialStore.AddSSHPublicKey(sshPublicKey)
+	sshCredentialStore.AddSSHPublicKey(ctx, sshPublicKey)
 
 	c := &RollingUpdateCluster{
 		Cloud:                   mockcloud,
@@ -86,7 +86,7 @@ func getTestSetupOS(t *testing.T) (*RollingUpdateCluster, *openstack.MockCloud)
 		ValidateTickDuration:    1 * time.Millisecond,
 		ValidateSuccessDuration: 5 * time.Millisecond,
 		ValidateCount:           2,
-		Ctx:                     context.Background(),
+		Ctx:                     ctx,
 		Cluster:                 cluster,
 		Clientset:               clientset,
 	}
@@ -100,11 +100,13 @@ var TempTestSkip = func(t *testing.T, message string) {
 }
 
 func TestRollingUpdateDisabledSurgeOS(t *testing.T) {
+	ctx := context.TODO()
+
 	TempTestSkip(t, "Failing in new release PR when build is not yet published")
 
 	t.Setenv("OS_REGION_NAME", "us-test1")
 
-	c, cloud := getTestSetupOS(t)
+	c, cloud := getTestSetupOS(t, ctx)
 
 	groups, igList := getGroupsAllNeedUpdateOS(t, c)
 	err := c.RollingUpdate(groups, igList)
@@ -126,7 +128,7 @@ func makeGroupOS(t *testing.T, groups map[string]*cloudinstances.CloudInstanceGr
 	switch role {
 	case kopsapi.InstanceGroupRoleNode:
 		newIg = testutils.BuildMinimalNodeInstanceGroup("nodes-"+subnet, subnet)
-	case kopsapi.InstanceGroupRoleMaster:
+	case kopsapi.InstanceGroupRoleControlPlane:
 		newIg = testutils.BuildMinimalMasterInstanceGroup(subnet)
 	case kopsapi.InstanceGroupRoleBastion:
 		newIg = testutils.BuildMinimalBastionInstanceGroup("bastion-"+subnet, subnet)
@@ -190,12 +192,12 @@ func makeGroupOS(t *testing.T, groups map[string]*cloudinstances.CloudInstanceGr
 func getGroupsAllNeedUpdateOS(t *testing.T, c *RollingUpdateCluster) (map[string]*cloudinstances.CloudInstanceGroup, *kopsapi.InstanceGroupList) {
 	groups := make(map[string]*cloudinstances.CloudInstanceGroup)
 	igList := &kopsapi.InstanceGroupList{}
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[0].Name, kopsapi.InstanceGroupRoleNode, 3, 3)
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[1].Name, kopsapi.InstanceGroupRoleNode, 3, 3)
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[0].Name, kopsapi.InstanceGroupRoleMaster, 1, 1)
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[1].Name, kopsapi.InstanceGroupRoleMaster, 1, 1)
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[2].Name, kopsapi.InstanceGroupRoleMaster, 1, 1)
-	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Subnets[0].Name, kopsapi.InstanceGroupRoleBastion, 1, 1)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[0].Name, kopsapi.InstanceGroupRoleNode, 3, 3)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[1].Name, kopsapi.InstanceGroupRoleNode, 3, 3)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[0].Name, kopsapi.InstanceGroupRoleControlPlane, 1, 1)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[1].Name, kopsapi.InstanceGroupRoleControlPlane, 1, 1)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[2].Name, kopsapi.InstanceGroupRoleControlPlane, 1, 1)
+	makeGroupOS(t, groups, igList, c, c.Cluster.Spec.Networking.Subnets[0].Name, kopsapi.InstanceGroupRoleBastion, 1, 1)
 	return groups, igList
 }
 
