@@ -85,28 +85,28 @@ func TestBootstrapUserData(t *testing.T) {
 		FileAssetSpecRoles []kops.InstanceGroupRole
 	}{
 		{
-			Role:               "Master",
+			Role:               "ControlPlane",
 			ExpectedFileIndex:  0,
 			HookSpecRoles:      []kops.InstanceGroupRole{""},
 			FileAssetSpecRoles: []kops.InstanceGroupRole{""},
 		},
 		{
-			Role:               "Master",
+			Role:               "ControlPlane",
 			ExpectedFileIndex:  0,
 			HookSpecRoles:      []kops.InstanceGroupRole{"Node"},
 			FileAssetSpecRoles: []kops.InstanceGroupRole{"Node"},
 		},
 		{
-			Role:               "Master",
+			Role:               "ControlPlane",
 			ExpectedFileIndex:  1,
-			HookSpecRoles:      []kops.InstanceGroupRole{"Master"},
-			FileAssetSpecRoles: []kops.InstanceGroupRole{"Master"},
+			HookSpecRoles:      []kops.InstanceGroupRole{"ControlPlane"},
+			FileAssetSpecRoles: []kops.InstanceGroupRole{"ControlPlane"},
 		},
 		{
-			Role:               "Master",
+			Role:               "ControlPlane",
 			ExpectedFileIndex:  2,
-			HookSpecRoles:      []kops.InstanceGroupRole{"Master", "Node"},
-			FileAssetSpecRoles: []kops.InstanceGroupRole{"Master", "Node"},
+			HookSpecRoles:      []kops.InstanceGroupRole{"ControlPlane", "Node"},
+			FileAssetSpecRoles: []kops.InstanceGroupRole{"ControlPlane", "Node"},
 		},
 		{
 			Role:               "Node",
@@ -123,26 +123,26 @@ func TestBootstrapUserData(t *testing.T) {
 		{
 			Role:               "Node",
 			ExpectedFileIndex:  3,
-			HookSpecRoles:      []kops.InstanceGroupRole{"Master"},
-			FileAssetSpecRoles: []kops.InstanceGroupRole{"Master"},
+			HookSpecRoles:      []kops.InstanceGroupRole{"ControlPlane"},
+			FileAssetSpecRoles: []kops.InstanceGroupRole{"ControlPlane"},
 		},
 		{
 			Role:               "Node",
 			ExpectedFileIndex:  5,
-			HookSpecRoles:      []kops.InstanceGroupRole{"Master", "Node"},
-			FileAssetSpecRoles: []kops.InstanceGroupRole{"Master", "Node"},
+			HookSpecRoles:      []kops.InstanceGroupRole{"ControlPlane", "Node"},
+			FileAssetSpecRoles: []kops.InstanceGroupRole{"ControlPlane", "Node"},
 		},
 	}
 
 	for i, x := range cs {
 		cluster := makeTestCluster(x.HookSpecRoles, x.FileAssetSpecRoles)
 		group := makeTestInstanceGroup(x.Role, x.HookSpecRoles, x.FileAssetSpecRoles)
-		c := &fi.ModelBuilderContext{
-			Tasks: make(map[string]fi.Task),
+		c := &fi.CloudupModelBuilderContext{
+			Tasks: make(map[string]fi.CloudupTask),
 		}
 
 		caTask := &fitasks.Keypair{
-			Name:    fi.String(fi.CertificateIDCA),
+			Name:    fi.PtrTo(fi.CertificateIDCA),
 			Subject: "cn=kubernetes",
 			Type:    "ca",
 		}
@@ -157,7 +157,7 @@ func TestBootstrapUserData(t *testing.T) {
 			"service-account",
 		} {
 			task := &fitasks.Keypair{
-				Name:    fi.String(keypair),
+				Name:    fi.PtrTo(keypair),
 				Subject: "cn=" + keypair,
 				Type:    "ca",
 			}
@@ -190,7 +190,7 @@ func TestBootstrapUserData(t *testing.T) {
 		}
 
 		require.Contains(t, c.Tasks, "BootstrapScript/testIG")
-		err = c.Tasks["BootstrapScript/testIG"].Run(&fi.Context{Cluster: cluster})
+		err = c.Tasks["BootstrapScript/testIG"].Run(&fi.CloudupContext{T: fi.CloudupSubContext{Cluster: cluster}})
 		require.NoError(t, err, "running task")
 
 		actual, err := fi.ResourceAsString(res)
@@ -219,17 +219,13 @@ func makeTestCluster(hookSpecRoles []kops.InstanceGroupRole, fileAssetSpecRoles
 				AWS: &kops.AWSSpec{},
 			},
 			KubernetesVersion: "1.20.0",
-			Subnets: []kops.ClusterSubnetSpec{
-				{Name: "test", Zone: "eu-west-1a"},
-			},
-			NonMasqueradeCIDR: "10.100.0.0/16",
 			EtcdClusters: []kops.EtcdClusterSpec{
 				{
 					Name: "main",
 					Members: []kops.EtcdMemberSpec{
 						{
 							Name:          "test",
-							InstanceGroup: fi.String("ig-1"),
+							InstanceGroup: fi.PtrTo("ig-1"),
 						},
 					},
 					Version: "3.1.11",
@@ -239,23 +235,22 @@ func makeTestCluster(hookSpecRoles []kops.InstanceGroupRole, fileAssetSpecRoles
 					Members: []kops.EtcdMemberSpec{
 						{
 							Name:          "test",
-							InstanceGroup: fi.String("ig-1"),
+							InstanceGroup: fi.PtrTo("ig-1"),
 						},
 					},
 					Version: "3.1.11",
 					Image:   "gcr.io/etcd-development/etcd:v3.1.11",
 				},
 			},
-			NetworkCIDR: "10.79.0.0/24",
 			CloudConfig: &kops.CloudConfiguration{
-				NodeTags: fi.String("something"),
+				NodeTags: fi.PtrTo("something"),
 			},
 			ContainerRuntime: "docker",
 			Containerd: &kops.ContainerdConfig{
-				LogLevel: fi.String("info"),
+				LogLevel: fi.PtrTo("info"),
 			},
 			Docker: &kops.DockerConfig{
-				LogLevel: fi.String("INFO"),
+				LogLevel: fi.PtrTo("INFO"),
 			},
 			KubeAPIServer: &kops.KubeAPIServerConfig{
 				Image: "CoreOS",
@@ -278,16 +273,22 @@ func makeTestCluster(hookSpecRoles []kops.InstanceGroupRole, fileAssetSpecRoles
 			Kubelet: &kops.KubeletConfigSpec{
 				KubeconfigPath: "/etc/kubernetes/config.txt",
 			},
-			MasterKubelet: &kops.KubeletConfigSpec{
+			ControlPlaneKubelet: &kops.KubeletConfigSpec{
 				KubeconfigPath: "/etc/kubernetes/config.cfg",
 			},
-			EgressProxy: &kops.EgressProxySpec{
-				HTTPProxy: kops.HTTPProxy{
-					Host: "example.com",
-					Port: 80,
+			Networking: kops.NetworkingSpec{
+				NetworkCIDR: "10.79.0.0/24",
+				Subnets: []kops.ClusterSubnetSpec{
+					{Name: "test", Zone: "eu-west-1a"},
 				},
+				EgressProxy: &kops.EgressProxySpec{
+					HTTPProxy: kops.HTTPProxy{
+						Host: "example.com",
+						Port: 80,
+					},
+				},
+				NonMasqueradeCIDR: "10.100.0.0/16",
 			},
-			Networking: &kops.NetworkingSpec{},
 			Hooks: []kops.HookSpec{
 				{
 					ExecContainer: &kops.ExecContainerAction{
