@@ -49,7 +49,7 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		if count == 0 {
 			return fmt.Errorf("no instance groups found")
 		}
-		c.APIServerCount = fi.Int32(int32(count))
+		c.APIServerCount = fi.PtrTo(int32(count))
 	}
 
 	// @question: should the question every be able to set this?
@@ -60,7 +60,7 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		if err != nil {
 			return err
 		}
-		c.StorageBackend = fi.String(fmt.Sprintf("etcd%d", sem.Major))
+		c.StorageBackend = fi.PtrTo(fmt.Sprintf("etcd%d", sem.Major))
 	}
 
 	if c.KubeletPreferredAddressTypes == nil {
@@ -74,7 +74,7 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 
 	if clusterSpec.Authentication != nil {
 		if clusterSpec.Authentication.Kopeio != nil {
-			c.AuthenticationTokenWebhookConfigFile = fi.String("/etc/kubernetes/authn.config")
+			c.AuthenticationTokenWebhookConfigFile = fi.PtrTo("/etc/kubernetes/authn.config")
 		}
 	}
 
@@ -82,9 +82,9 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		// Do nothing - use the default as defined by the apiserver
 		// (this won't happen anyway because of our default logic)
 	} else if clusterSpec.Authorization.AlwaysAllow != nil {
-		clusterSpec.KubeAPIServer.AuthorizationMode = fi.String("AlwaysAllow")
+		clusterSpec.KubeAPIServer.AuthorizationMode = fi.PtrTo("AlwaysAllow")
 	} else if clusterSpec.Authorization.RBAC != nil {
-		clusterSpec.KubeAPIServer.AuthorizationMode = fi.String("Node,RBAC")
+		clusterSpec.KubeAPIServer.AuthorizationMode = fi.PtrTo("Node,RBAC")
 	}
 
 	if err := b.configureAggregation(clusterSpec); err != nil {
@@ -110,6 +110,8 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		c.CloudProvider = "openstack"
 	case kops.CloudProviderAzure:
 		c.CloudProvider = "azure"
+	case kops.CloudProviderScaleway:
+		c.CloudProvider = "external"
 	default:
 		return fmt.Errorf("unknown cloudprovider %q", clusterSpec.GetCloudProvider())
 	}
@@ -127,8 +129,8 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		c.BindAddress = "0.0.0.0"
 	}
 
-	c.AllowPrivileged = fi.Bool(true)
-	c.ServiceClusterIPRange = clusterSpec.ServiceClusterIPRange
+	c.AllowPrivileged = fi.PtrTo(true)
+	c.ServiceClusterIPRange = clusterSpec.Networking.ServiceClusterIPRange
 	c.EtcdServers = nil
 	c.EtcdServersOverrides = nil
 
@@ -161,7 +163,7 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 	}
 
 	// We make sure to disable AnonymousAuth
-	c.AnonymousAuth = fi.Bool(false)
+	c.AnonymousAuth = fi.PtrTo(false)
 
 	// We query via the kube-apiserver-healthcheck proxy, which listens on port 3990
 	c.InsecureBindAddress = ""
@@ -169,9 +171,9 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 
 	// If metrics-server is enabled, we want aggregator routing enabled so that requests are load balanced.
 	metricsServer := clusterSpec.MetricsServer
-	if metricsServer != nil && fi.BoolValue(metricsServer.Enabled) {
+	if metricsServer != nil && fi.ValueOf(metricsServer.Enabled) {
 		if c.EnableAggregatorRouting == nil {
-			c.EnableAggregatorRouting = fi.Bool(true)
+			c.EnableAggregatorRouting = fi.PtrTo(true)
 		}
 	}
 
@@ -179,16 +181,10 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		c.FeatureGates = make(map[string]string)
 	}
 
-	if clusterSpec.CloudConfig != nil && clusterSpec.CloudConfig.AWSEBSCSIDriver != nil && fi.BoolValue(clusterSpec.CloudConfig.AWSEBSCSIDriver.Enabled) {
+	if clusterSpec.CloudProvider.AWS != nil && clusterSpec.CloudProvider.AWS.EBSCSIDriver != nil && fi.ValueOf(clusterSpec.CloudProvider.AWS.EBSCSIDriver.Enabled) {
 
-		if b.IsKubernetesLT("1.21.0") {
-			if _, found := c.FeatureGates["CSIMigrationAWSComplete"]; !found {
-				c.FeatureGates["CSIMigrationAWSComplete"] = "true"
-			}
-		} else {
-			if _, found := c.FeatureGates["InTreePluginAWSUnregister"]; !found {
-				c.FeatureGates["InTreePluginAWSUnregister"] = "true"
-			}
+		if _, found := c.FeatureGates["InTreePluginAWSUnregister"]; !found {
+			c.FeatureGates["InTreePluginAWSUnregister"] = "true"
 		}
 
 		if _, found := c.FeatureGates["CSIMigrationAWS"]; !found {
@@ -196,12 +192,6 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(o interface{}) error {
 		}
 	}
 
-	if b.IsKubernetesLT("1.20") && clusterSpec.ServiceAccountIssuerDiscovery != nil && fi.BoolValue(&clusterSpec.ServiceAccountIssuerDiscovery.EnableAWSOIDCProvider) {
-		if _, found := c.FeatureGates["ServiceAccountIssuerDiscovery"]; !found {
-			c.FeatureGates["ServiceAccountIssuerDiscovery"] = "true"
-		}
-	}
-
 	return nil
 }
 
@@ -213,12 +203,12 @@ func (b *KubeAPIServerOptionsBuilder) buildAPIServerCount(clusterSpec *kops.Clus
 
 	//count := 0
 	//for _, ig := range b.InstanceGroups {
-	//	if !ig.IsMaster() {
+	//	if !ig.IsControlPlane() {
 	//		continue
 	//	}
-	//	size := fi.IntValue(ig.Spec.MaxSize)
+	//	size := fi.ValueOf(ig.Spec.MaxSize)
 	//	if size == 0 {
-	//		size = fi.IntValue(ig.Spec.MinSize)
+	//		size = fi.ValueOf(ig.Spec.MinSize)
 	//	}
 	//	count += size
 	//}
