@@ -28,7 +28,6 @@ import (
 	"k8s.io/kops/pkg/assets"
 	"k8s.io/kops/pkg/k8sversion"
 	"k8s.io/kops/upup/pkg/fi"
-	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
 	"k8s.io/kops/util/pkg/vfs"
 
 	"github.com/blang/semver/v4"
@@ -80,9 +79,9 @@ func UsesCNI(networking *kops.NetworkingSpec) bool {
 }
 
 func WellKnownServiceIP(clusterSpec *kops.ClusterSpec, id int) (net.IP, error) {
-	_, cidr, err := net.ParseCIDR(clusterSpec.ServiceClusterIPRange)
+	_, cidr, err := net.ParseCIDR(clusterSpec.Networking.ServiceClusterIPRange)
 	if err != nil {
-		return nil, fmt.Errorf("error parsing ServiceClusterIPRange %q: %v", clusterSpec.ServiceClusterIPRange, err)
+		return nil, fmt.Errorf("error parsing ServiceClusterIPRange %q: %v", clusterSpec.Networking.ServiceClusterIPRange, err)
 	}
 
 	ip4 := cidr.IP.To4()
@@ -108,7 +107,7 @@ func WellKnownServiceIP(clusterSpec *kops.ClusterSpec, id int) (net.IP, error) {
 		return serviceIP, nil
 	}
 
-	return nil, fmt.Errorf("unexpected IP address type for ServiceClusterIPRange: %s", clusterSpec.ServiceClusterIPRange)
+	return nil, fmt.Errorf("unexpected IP address type for ServiceClusterIPRange: %s", clusterSpec.Networking.ServiceClusterIPRange)
 }
 
 func IsBaseURL(kubernetesVersion string) bool {
@@ -168,12 +167,7 @@ func Image(component string, clusterSpec *kops.ClusterSpec, assetsBuilder *asset
 	return image, nil
 }
 
-// GCETagForRole returns the (network) tag for GCE instances in the given instance group role.
-func GCETagForRole(clusterName string, role kops.InstanceGroupRole) string {
-	return gce.SafeClusterName(clusterName) + "-" + gce.GceLabelNameRolePrefix + strings.ToLower(string(role))
-}
-
 // IsCertManagerEnabled returns true if the cluster has the capability to handle cert-manager PKI
 func IsCertManagerEnabled(cluster *kops.Cluster) bool {
-	return cluster.Spec.CertManager != nil && fi.BoolValue(cluster.Spec.CertManager.Enabled)
+	return cluster.Spec.CertManager != nil && fi.ValueOf(cluster.Spec.CertManager.Enabled)
 }
