@@ -48,15 +48,33 @@ func (b *GCPCloudControllerManagerOptionsBuilder) BuildOptions(options interface
 
 	// No significant downside to always doing a leader election.
 	// Also, having multiple control plane nodes requires leader election.
-	ccmConfig.LeaderElection = &kops.LeaderElectionConfiguration{LeaderElect: fi.Bool(true)}
+	ccmConfig.LeaderElection = &kops.LeaderElectionConfiguration{LeaderElect: fi.PtrTo(true)}
 
 	// CCM interacts directly with the GCP API, use the name safe for GCP
 	ccmConfig.ClusterName = gce.SafeClusterName(b.ClusterName)
-	ccmConfig.AllocateNodeCIDRs = fi.Bool(true)
-	ccmConfig.CIDRAllocatorType = fi.String("CloudAllocator")
+	ccmConfig.AllocateNodeCIDRs = fi.PtrTo(true)
+	ccmConfig.CIDRAllocatorType = fi.PtrTo("CloudAllocator")
 	if ccmConfig.ClusterCIDR == "" {
-		ccmConfig.ClusterCIDR = clusterSpec.PodCIDR
+		ccmConfig.ClusterCIDR = clusterSpec.Networking.PodCIDR
 	}
+
+	if clusterSpec.Networking.GCE != nil {
+		// "GCE" networking mode is called "ip-alias" or "vpc-native" on GKE.
+		// We don't need to configure routes if we are using "real" IPs.
+		ccmConfig.ConfigureCloudRoutes = fi.PtrTo(false)
+	}
+
+	if ccmConfig.Controllers == nil {
+		ccmConfig.Controllers = []string{
+			"*",
+
+			// Don't run gkenetworkparamset controller, looks for some CRDs (GKENetworkParamSet and Network) which are only installed on GKE
+			// However, the version we're current running doesn't support this controller anyway, so we need to introduce this later,
+			// possibly based on the image version.
+			// "-gkenetworkparams",
+		}
+	}
+
 	if ccmConfig.Image == "" {
 		// TODO: Implement CCM image publishing
 		switch b.KubernetesVersion.Minor {
@@ -68,7 +86,7 @@ func (b *GCPCloudControllerManagerOptionsBuilder) BuildOptions(options interface
 	}
 
 	if b.IsKubernetesGTE("1.24") && b.IsKubernetesLT("1.25") {
-		ccmConfig.EnableLeaderMigration = fi.Bool(true)
+		ccmConfig.EnableLeaderMigration = fi.PtrTo(true)
 	}
 
 	return nil
