@@ -53,24 +53,18 @@ func (b *KubeSchedulerOptionsBuilder) BuildOptions(o interface{}) error {
 	if config.LeaderElection == nil {
 		//  Doesn't seem to be any real downside to always doing a leader election
 		config.LeaderElection = &kops.LeaderElectionConfiguration{
-			LeaderElect: fi.Bool(true),
+			LeaderElect: fi.PtrTo(true),
 		}
 	}
 
-	if clusterSpec.CloudConfig != nil && clusterSpec.CloudConfig.AWSEBSCSIDriver != nil && fi.BoolValue(clusterSpec.CloudConfig.AWSEBSCSIDriver.Enabled) {
+	if clusterSpec.CloudProvider.AWS != nil && clusterSpec.CloudProvider.AWS.EBSCSIDriver != nil && fi.ValueOf(clusterSpec.CloudProvider.AWS.EBSCSIDriver.Enabled) {
 
 		if config.FeatureGates == nil {
 			config.FeatureGates = make(map[string]string)
 		}
 
-		if b.IsKubernetesLT("1.21.0") {
-			if _, found := config.FeatureGates["CSIMigrationAWSComplete"]; !found {
-				config.FeatureGates["CSIMigrationAWSComplete"] = "true"
-			}
-		} else {
-			if _, found := config.FeatureGates["InTreePluginAWSUnregister"]; !found {
-				config.FeatureGates["InTreePluginAWSUnregister"] = "true"
-			}
+		if _, found := config.FeatureGates["InTreePluginAWSUnregister"]; !found {
+			config.FeatureGates["InTreePluginAWSUnregister"] = "true"
 		}
 
 		if _, found := config.FeatureGates["CSIMigrationAWS"]; !found {
