@@ -20,7 +20,6 @@ import (
 	"fmt"
 
 	"k8s.io/kops/pkg/apis/kops"
-	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/do"
 	"k8s.io/kops/upup/pkg/fi/cloudup/dotasks"
@@ -32,9 +31,9 @@ type APILoadBalancerModelBuilder struct {
 	Lifecycle fi.Lifecycle
 }
 
-var _ fi.ModelBuilder = &APILoadBalancerModelBuilder{}
+var _ fi.CloudupModelBuilder = &APILoadBalancerModelBuilder{}
 
-func (b *APILoadBalancerModelBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *APILoadBalancerModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 	// Configuration where a load balancer fronts the API
 	if !b.UseLoadBalancerForAPI() {
 		return nil
@@ -61,24 +60,24 @@ func (b *APILoadBalancerModelBuilder) Build(c *fi.ModelBuilderContext) error {
 
 	// Create LoadBalancer for API LB
 	loadbalancer := &dotasks.LoadBalancer{
-		Name:       fi.String(loadbalancerName),
-		Region:     fi.String(b.Cluster.Spec.Subnets[0].Region),
-		DropletTag: fi.String(clusterMasterTag),
+		Name:       fi.PtrTo(loadbalancerName),
+		Region:     fi.PtrTo(b.Cluster.Spec.Networking.Subnets[0].Region),
+		DropletTag: fi.PtrTo(clusterMasterTag),
 		Lifecycle:  b.Lifecycle,
 	}
 
-	if b.Cluster.Spec.NetworkID != "" {
-		loadbalancer.VPCUUID = fi.String(b.Cluster.Spec.NetworkID)
-	} else if b.Cluster.Spec.NetworkCIDR != "" {
+	if b.Cluster.Spec.Networking.NetworkID != "" {
+		loadbalancer.VPCUUID = fi.PtrTo(b.Cluster.Spec.Networking.NetworkID)
+	} else if b.Cluster.Spec.Networking.NetworkCIDR != "" {
 		vpcName := "vpc-" + clusterName
-		loadbalancer.VPCName = fi.String(vpcName)
-		loadbalancer.NetworkCIDR = fi.String(b.Cluster.Spec.NetworkCIDR)
+		loadbalancer.VPCName = fi.PtrTo(vpcName)
+		loadbalancer.NetworkCIDR = fi.PtrTo(b.Cluster.Spec.Networking.NetworkCIDR)
 	}
 
 	c.AddTask(loadbalancer)
 
 	// Temporarily do not know the role of the following function
-	if dns.IsGossipHostname(b.Cluster.Name) || b.UsePrivateDNS() {
+	if b.Cluster.IsGossip() || b.Cluster.UsesPrivateDNS() || b.Cluster.UsesNoneDNS() {
 		// Ensure the LB hostname is included in the TLS certificate,
 		// if we're not going to use an alias for it
 		loadbalancer.ForAPIServer = true
