@@ -102,10 +102,10 @@ func (b *Builder) loadClusterPackage(u *unstructured.Unstructured) (*Package, er
 	addon := &Package{
 		Manifest: manifestBytes,
 		Spec: channelsapi.AddonSpec{
-			Name:     fi.String(operatorKey),
+			Name:     fi.PtrTo(operatorKey),
 			Id:       id,
 			Selector: map[string]string{"k8s-addon": operatorKey},
-			Manifest: fi.String(location),
+			Manifest: fi.PtrTo(location),
 		},
 	}
 	return addon, nil
@@ -118,7 +118,7 @@ func CreateAddons(channel *kops.Channel, kubernetesVersion *semver.Version, clus
 		return addons, nil
 	}
 
-	if cluster.Spec.Networking != nil && cluster.Spec.Networking.Kopeio != nil {
+	if cluster.Spec.Networking.Kopeio != nil {
 		// TODO: Check that we haven't manually loaded a kopeio-networking operator
 		// TODO: Check that we haven't manually created a kopeio-networking CRD
 
