@@ -30,7 +30,6 @@ import (
 	"github.com/aws/aws-sdk-go/service/sqs"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 )
 
@@ -53,8 +52,8 @@ func (q *SQS) CompareWithID() *string {
 	return q.ARN
 }
 
-func (q *SQS) Find(c *fi.Context) (*SQS, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (q *SQS) Find(c *fi.CloudupContext) (*SQS, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	if q.Name == nil {
 		return nil, nil
@@ -137,8 +136,8 @@ func (q *SQS) Find(c *fi.Context) (*SQS, error) {
 	return actual, nil
 }
 
-func (q *SQS) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(q, c)
+func (q *SQS) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(q, c)
 }
 
 func (q *SQS) CheckChanges(a, e, changes *SQS) error {
@@ -216,54 +215,6 @@ func (e *SQS) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_sqs_queue", *e.Name, "arn")
 }
 
-type cloudformationSQSQueue struct {
-	QueueName              *string             `json:"QueueName"`
-	MessageRetentionPeriod int                 `json:"MessageRetentionPeriod"`
-	Tags                   []cloudformationTag `json:"Tags,omitempty"`
-}
-
-type cloudformationSQSQueuePolicy struct {
-	Queues         []*cloudformation.Literal `json:"Queues"`
-	PolicyDocument map[string]interface{}    `json:"PolicyDocument"`
-	Tags           []cloudformationTag       `json:"Tags,omitempty"`
-}
-
-func (_ *SQS) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *SQS) error {
-	cfQueue := &cloudformationSQSQueue{
-		QueueName:              e.Name,
-		MessageRetentionPeriod: e.MessageRetentionPeriod,
-		Tags:                   buildCloudformationTags(e.Tags),
-	}
-
-	err := t.RenderResource("AWS::SQS::Queue", *e.Name, cfQueue)
-	if err != nil {
-		return err
-	}
-
-	// convert Policy string into json
-	jsonString, err := fi.ResourceAsBytes(e.Policy)
-	if err != nil {
-		return err
-	}
-	data := make(map[string]interface{})
-	err = json.Unmarshal(jsonString, &data)
-	if err != nil {
-		return fmt.Errorf("error parsing SQS PolicyDocument: %v", err)
-	}
-
-	cfQueueRef := cloudformation.Ref("AWS::SQS::Queue", fi.StringValue(e.Name))
-
-	cfQueuePolicy := &cloudformationSQSQueuePolicy{
-		Queues:         []*cloudformation.Literal{cfQueueRef},
-		PolicyDocument: data,
-	}
-	return t.RenderResource("AWS::SQS::QueuePolicy", *e.Name+"Policy", cfQueuePolicy)
-}
-
-func (e *SQS) CloudformationLink() *cloudformation.Literal {
-	return cloudformation.Ref("AWS::SQS::Queue", *e.Name)
-}
-
 // change tags to format required by CreateQueue
 func convertTagsToPointers(tags map[string]string) map[string]*string {
 	newTags := map[string]*string{}
