@@ -22,7 +22,6 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/autoscaling/autoscalingiface"
-	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
 	"github.com/aws/aws-sdk-go/service/elb"
@@ -78,17 +77,16 @@ func BuildMockAWSCloud(region string, zoneLetters string) *MockAWSCloud {
 }
 
 type MockCloud struct {
-	MockAutoscaling    autoscalingiface.AutoScalingAPI
-	MockCloudFormation *cloudformation.CloudFormation
-	MockEC2            ec2iface.EC2API
-	MockIAM            iamiface.IAMAPI
-	MockRoute53        route53iface.Route53API
-	MockELB            elbiface.ELBAPI
-	MockELBV2          elbv2iface.ELBV2API
-	MockSpotinst       spotinst.Cloud
-	MockSQS            sqsiface.SQSAPI
-	MockEventBridge    eventbridgeiface.EventBridgeAPI
-	MockSSM            ssmiface.SSMAPI
+	MockAutoscaling autoscalingiface.AutoScalingAPI
+	MockEC2         ec2iface.EC2API
+	MockIAM         iamiface.IAMAPI
+	MockRoute53     route53iface.Route53API
+	MockELB         elbiface.ELBAPI
+	MockELBV2       elbv2iface.ELBV2API
+	MockSpotinst    spotinst.Cloud
+	MockSQS         sqsiface.SQSAPI
+	MockEventBridge eventbridgeiface.EventBridgeAPI
+	MockSSM         ssmiface.SSMAPI
 }
 
 func (c *MockAWSCloud) DeleteGroup(g *cloudinstances.CloudInstanceGroup) error {
@@ -215,6 +213,10 @@ func (c *MockAWSCloud) DescribeELBV2Tags(loadBalancerArns []string) (map[string]
 	return describeELBV2Tags(c, loadBalancerArns)
 }
 
+func (c *MockAWSCloud) FindELBV2NetworkInterfacesByName(vpcID, loadBalancerName string) ([]*ec2.NetworkInterface, error) {
+	return nil, nil
+}
+
 func (c *MockAWSCloud) DescribeInstance(instanceID string) (*ec2.Instance, error) {
 	return nil, fmt.Errorf("MockAWSCloud DescribeInstance not implemented")
 }
@@ -234,13 +236,6 @@ func (c *MockAWSCloud) WithTags(tags map[string]string) AWSCloud {
 	return m
 }
 
-func (c *MockAWSCloud) CloudFormation() *cloudformation.CloudFormation {
-	if c.MockEC2 == nil {
-		klog.Fatalf("MockAWSCloud MockCloudFormation not set")
-	}
-	return c.MockCloudFormation
-}
-
 func (c *MockAWSCloud) EC2() ec2iface.EC2API {
 	if c.MockEC2 == nil {
 		klog.Fatalf("MockAWSCloud MockEC2 not set")
@@ -322,7 +317,7 @@ func (c *MockAWSCloud) GetApiIngressStatus(cluster *kops.Cluster) ([]fi.ApiIngre
 // DefaultInstanceType determines an instance type for the specified cluster & instance group
 func (c *MockAWSCloud) DefaultInstanceType(cluster *kops.Cluster, ig *kops.InstanceGroup) (string, error) {
 	switch ig.Spec.Role {
-	case kops.InstanceGroupRoleMaster, kops.InstanceGroupRoleAPIServer:
+	case kops.InstanceGroupRoleControlPlane, kops.InstanceGroupRoleAPIServer:
 		return "m3.medium", nil
 	case kops.InstanceGroupRoleNode:
 		return "t2.medium", nil
@@ -336,7 +331,7 @@ func (c *MockAWSCloud) DefaultInstanceType(cluster *kops.Cluster, ig *kops.Insta
 // DescribeInstanceType calls ec2.DescribeInstanceType to get information for a particular instance type
 func (c *MockAWSCloud) DescribeInstanceType(instanceType string) (*ec2.InstanceTypeInfo, error) {
 	if instanceType == "t2.invalidType" {
-		return nil, fmt.Errorf("invalid instance type specified: t2.invalidType")
+		return nil, fmt.Errorf("invalid instance type %q specified", "t2.invalidType")
 	}
 	info := &ec2.InstanceTypeInfo{
 		NetworkInfo: &ec2.NetworkInfo{
