@@ -19,7 +19,7 @@ package azuretasks
 import (
 	"context"
 
-	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2020-06-01/network"
+	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2022-05-01/network"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
@@ -37,8 +37,9 @@ type PublicIPAddress struct {
 }
 
 var (
-	_ fi.Task          = &PublicIPAddress{}
-	_ fi.CompareWithID = &PublicIPAddress{}
+	_ fi.CloudupTask          = &PublicIPAddress{}
+	_ fi.CompareWithID        = &PublicIPAddress{}
+	_ fi.CloudupTaskNormalize = &PublicIPAddress{}
 )
 
 // CompareWithID returns the Name of the Public IP Address
@@ -47,8 +48,8 @@ func (p *PublicIPAddress) CompareWithID() *string {
 }
 
 // Find discovers the Public IP Address in the cloud provider
-func (p *PublicIPAddress) Find(c *fi.Context) (*PublicIPAddress, error) {
-	cloud := c.Cloud.(azure.AzureCloud)
+func (p *PublicIPAddress) Find(c *fi.CloudupContext) (*PublicIPAddress, error) {
+	cloud := c.T.Cloud.(azure.AzureCloud)
 	l, err := cloud.PublicIPAddress().List(context.TODO(), *p.ResourceGroup.Name)
 	if err != nil {
 		return nil, err
@@ -75,10 +76,14 @@ func (p *PublicIPAddress) Find(c *fi.Context) (*PublicIPAddress, error) {
 	}, nil
 }
 
+func (p *PublicIPAddress) Normalize(c *fi.CloudupContext) error {
+	c.T.Cloud.(azure.AzureCloud).AddClusterTags(p.Tags)
+	return nil
+}
+
 // Run implements fi.Task.Run.
-func (p *PublicIPAddress) Run(c *fi.Context) error {
-	c.Cloud.(azure.AzureCloud).AddClusterTags(p.Tags)
-	return fi.DefaultDeltaRunMethod(p, c)
+func (p *PublicIPAddress) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(p, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -101,9 +106,9 @@ func (*PublicIPAddress) CheckChanges(a, e, changes *PublicIPAddress) error {
 // RenderAzure creates or updates a Public IP Address.
 func (*PublicIPAddress) RenderAzure(t *azure.AzureAPITarget, a, e, changes *PublicIPAddress) error {
 	if a == nil {
-		klog.Infof("Creating a new Public IP Address with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Creating a new Public IP Address with name: %s", fi.ValueOf(e.Name))
 	} else {
-		klog.Infof("Updating a Public IP Address with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Updating a Public IP Address with name: %s", fi.ValueOf(e.Name))
 	}
 
 	p := network.PublicIPAddress{
@@ -111,7 +116,10 @@ func (*PublicIPAddress) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Publ
 		Name:     to.StringPtr(*e.Name),
 		PublicIPAddressPropertiesFormat: &network.PublicIPAddressPropertiesFormat{
 			PublicIPAddressVersion:   network.IPv4,
-			PublicIPAllocationMethod: network.Dynamic,
+			PublicIPAllocationMethod: network.Static,
+		},
+		Sku: &network.PublicIPAddressSku{
+			Name: network.PublicIPAddressSkuNameStandard,
 		},
 		Tags: e.Tags,
 	}
