@@ -19,7 +19,7 @@ package azuretasks
 import (
 	"context"
 
-	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2020-06-01/network"
+	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2022-05-01/network"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
@@ -38,7 +38,7 @@ type Subnet struct {
 }
 
 var (
-	_ fi.Task          = &Subnet{}
+	_ fi.CloudupTask   = &Subnet{}
 	_ fi.CompareWithID = &Subnet{}
 )
 
@@ -48,8 +48,8 @@ func (s *Subnet) CompareWithID() *string {
 }
 
 // Find discovers the Subnet in the cloud provider.
-func (s *Subnet) Find(c *fi.Context) (*Subnet, error) {
-	cloud := c.Cloud.(azure.AzureCloud)
+func (s *Subnet) Find(c *fi.CloudupContext) (*Subnet, error) {
+	cloud := c.T.Cloud.(azure.AzureCloud)
 	l, err := cloud.Subnet().List(context.TODO(), *s.ResourceGroup.Name, *s.VirtualNetwork.Name)
 	if err != nil {
 		return nil, err
@@ -68,6 +68,7 @@ func (s *Subnet) Find(c *fi.Context) (*Subnet, error) {
 	return &Subnet{
 		Name:      s.Name,
 		Lifecycle: s.Lifecycle,
+		Shared:    s.Shared,
 		ResourceGroup: &ResourceGroup{
 			Name: s.ResourceGroup.Name,
 		},
@@ -79,8 +80,8 @@ func (s *Subnet) Find(c *fi.Context) (*Subnet, error) {
 }
 
 // Run implements fi.Task.Run.
-func (s *Subnet) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(s, c)
+func (s *Subnet) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(s, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -103,9 +104,9 @@ func (*Subnet) CheckChanges(a, e, changes *Subnet) error {
 // RenderAzure creates or updates a subnet.
 func (*Subnet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *Subnet) error {
 	if a == nil {
-		klog.Infof("Creating a new Subnet with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Creating a new Subnet with name: %s", fi.ValueOf(e.Name))
 	} else {
-		klog.Infof("Updating a Subnet with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Updating a Subnet with name: %s", fi.ValueOf(e.Name))
 	}
 
 	// TODO(kenji): Be able to specify security groups.
