@@ -24,7 +24,7 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2020-06-01/compute"
+	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
@@ -84,7 +84,7 @@ func newTestVMScaleSet() *VMScaleSet {
 		ComputerNamePrefix: to.StringPtr("cprefix"),
 		AdminUser:          to.StringPtr("admin"),
 		SSHPublicKey:       to.StringPtr("ssh"),
-		CustomData:         fi.NewStringResource("custom"),
+		UserData:           fi.NewStringResource("custom"),
 		Tags:               map[string]*string{},
 		Zones:              []string{"zone1"},
 	}
@@ -113,17 +113,17 @@ func TestVMScaleSetRenderAzure(t *testing.T) {
 	if a, e := *actual.Sku.Capacity, *expected.Capacity; a != e {
 		t.Errorf("unexpected SKU Capacity: expected %d, but got %d", e, a)
 	}
-	actualCData, err := base64.StdEncoding.DecodeString(
-		*actual.VirtualMachineProfile.OsProfile.CustomData)
+	actualUserData, err := base64.StdEncoding.DecodeString(
+		*actual.VirtualMachineProfile.UserData)
 	if err != nil {
-		t.Fatalf("failed to decode custom data: %s", err)
+		t.Fatalf("failed to decode user data: %s", err)
 	}
-	expectedCData, err := fi.ResourceAsBytes(expected.CustomData)
+	expectedUserData, err := fi.ResourceAsBytes(expected.UserData)
 	if err != nil {
-		t.Fatalf("failed to get custom data: %s", err)
+		t.Fatalf("failed to get user data: %s", err)
 	}
-	if !bytes.Equal(actualCData, expectedCData) {
-		t.Errorf("unexpected custom data: expected %v, but got %v", expectedCData, actualCData)
+	if !bytes.Equal(actualUserData, expectedUserData) {
+		t.Errorf("unexpected user data: expected %v, but got %v", expectedUserData, actualUserData)
 	}
 
 	if expected.PrincipalID == nil {
@@ -137,8 +137,10 @@ func TestVMScaleSetRenderAzure(t *testing.T) {
 
 func TestVMScaleSetFind(t *testing.T) {
 	cloud := NewMockAzureCloud("eastus")
-	ctx := &fi.Context{
-		Cloud: cloud,
+	ctx := &fi.CloudupContext{
+		T: fi.CloudupSubContext{
+			Cloud: cloud,
+		},
 	}
 
 	rg := &ResourceGroup{
@@ -158,11 +160,10 @@ func TestVMScaleSetFind(t *testing.T) {
 	}
 
 	// Create a VM ScaleSet.
-	customData := []byte("custom")
+	userData := []byte("custom")
 	osProfile := &compute.VirtualMachineScaleSetOSProfile{
 		ComputerNamePrefix: to.StringPtr("prefix"),
 		AdminUsername:      to.StringPtr("admin"),
-		CustomData:         to.StringPtr(base64.RawStdEncoding.EncodeToString(customData)),
 		LinuxConfiguration: &compute.LinuxConfiguration{
 			SSH: &compute.SSHConfiguration{
 				PublicKeys: &[]compute.SSHPublicKey{
@@ -248,6 +249,7 @@ func TestVMScaleSetFind(t *testing.T) {
 			VirtualMachineProfile: &compute.VirtualMachineScaleSetVMProfile{
 				OsProfile:      osProfile,
 				StorageProfile: storageProfile,
+				UserData:       to.StringPtr(base64.RawStdEncoding.EncodeToString(userData)),
 				NetworkProfile: &compute.VirtualMachineScaleSetNetworkProfile{
 					NetworkInterfaceConfigurations: &[]compute.VirtualMachineScaleSetNetworkConfiguration{
 						networkConfig,
@@ -301,18 +303,24 @@ func TestVMScaleSetFind(t *testing.T) {
 
 func TestVMScaleSetRun(t *testing.T) {
 	cloud := NewMockAzureCloud("eastus")
-	ctx := &fi.Context{
-		Cloud:  cloud,
+	ctx := &fi.CloudupContext{
+		T: fi.CloudupSubContext{
+			Cloud: cloud,
+		},
 		Target: azure.NewAzureAPITarget(cloud),
 	}
 
 	vmss := newTestVMScaleSet()
-	err := vmss.Run(ctx)
+	err := vmss.Normalize(ctx)
+	if err != nil {
+		t.Fatalf("unexpected error: %s", err)
+	}
+	err = vmss.Run(ctx)
 	if err != nil {
 		t.Fatalf("unexpected error: %s", err)
 	}
 	expectedTags := map[string]*string{
-		azure.TagClusterName: fi.String(testClusterName),
+		azure.TagClusterName: fi.PtrTo(testClusterName),
 	}
 	if a, e := vmss.Tags, expectedTags; !reflect.DeepEqual(a, e) {
 		t.Errorf("unexpected tags: expected %+v, but got %+v", e, a)
