@@ -26,6 +26,7 @@ import (
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/diff"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/util/pkg/architectures"
 )
 
 func TestRemoveSharedPrefix(t *testing.T) {
@@ -94,7 +95,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Kubenet: &api.KubenetNetworkingSpec{},
 					},
 				},
@@ -106,7 +107,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						External: &api.ExternalNetworkingSpec{},
 					},
 				},
@@ -118,7 +119,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						CNI: &api.CNINetworkingSpec{},
 					},
 				},
@@ -130,7 +131,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Kopeio: &api.KopeioNetworkingSpec{},
 					},
 				},
@@ -142,7 +143,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Kopeio: &api.KopeioNetworkingSpec{},
 					},
 				},
@@ -154,7 +155,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Weave: &api.WeaveNetworkingSpec{},
 					},
 				},
@@ -166,7 +167,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Flannel: &api.FlannelNetworkingSpec{
 							Backend: "vxlan",
 						},
@@ -180,7 +181,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Flannel: &api.FlannelNetworkingSpec{
 							Backend: "vxlan",
 						},
@@ -194,7 +195,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Flannel: &api.FlannelNetworkingSpec{
 							Backend: "udp",
 						},
@@ -208,7 +209,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Calico: &api.CalicoNetworkingSpec{},
 					},
 				},
@@ -220,7 +221,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Canal: &api.CanalNetworkingSpec{},
 					},
 				},
@@ -233,10 +234,10 @@ func TestSetupNetworking(t *testing.T) {
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
 					KubeProxy: &api.KubeProxyConfig{
-						Enabled: fi.Bool(false),
+						Enabled: fi.PtrTo(false),
 					},
-					Networking: &api.NetworkingSpec{
-						Kuberouter: &api.KuberouterNetworkingSpec{},
+					Networking: api.NetworkingSpec{
+						KubeRouter: &api.KuberouterNetworkingSpec{},
 					},
 				},
 			},
@@ -247,7 +248,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						AmazonVPC: &api.AmazonVPCNetworkingSpec{},
 					},
 				},
@@ -259,7 +260,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						AmazonVPC: &api.AmazonVPCNetworkingSpec{},
 					},
 				},
@@ -272,9 +273,9 @@ func TestSetupNetworking(t *testing.T) {
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
 					KubeProxy: &api.KubeProxyConfig{
-						Enabled: fi.Bool(false),
+						Enabled: fi.PtrTo(false),
 					},
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Cilium: &api.CiliumNetworkingSpec{
 							EnableNodePort: true,
 						},
@@ -289,9 +290,9 @@ func TestSetupNetworking(t *testing.T) {
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
 					KubeProxy: &api.KubeProxyConfig{
-						Enabled: fi.Bool(false),
+						Enabled: fi.PtrTo(false),
 					},
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						Cilium: &api.CiliumNetworkingSpec{
 							EnableNodePort: true,
 							EtcdManaged:    true,
@@ -306,7 +307,7 @@ func TestSetupNetworking(t *testing.T) {
 			},
 			expected: api.Cluster{
 				Spec: api.ClusterSpec{
-					Networking: &api.NetworkingSpec{
+					Networking: api.NetworkingSpec{
 						GCE: &api.GCENetworkingSpec{},
 					},
 				},
@@ -334,3 +335,112 @@ func TestSetupNetworking(t *testing.T) {
 		}
 	}
 }
+
+func TestDefaultImage(t *testing.T) {
+	tests := []struct {
+		cluster      *api.Cluster
+		architecture architectures.Architecture
+		expected     string
+	}{
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						AWS: &api.AWSSpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     "099720109477/ubuntu/images/hvm-ssd/ubuntu-focal-20.04-amd64-server-20221018",
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						AWS: &api.AWSSpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureArm64,
+			expected:     "099720109477/ubuntu/images/hvm-ssd/ubuntu-focal-20.04-arm64-server-20221018",
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						Azure: &api.AzureSpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     "Canonical:0001-com-ubuntu-server-focal:20_04-lts-gen2:20.04.202210180",
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						GCE: &api.GCESpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     "ubuntu-os-cloud/ubuntu-2004-focal-v20221018",
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						DO: &api.DOSpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     defaultDOImage,
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						Hetzner: &api.HetznerSpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     defaultHetznerImage,
+		},
+		{
+			cluster: &api.Cluster{
+				Spec: api.ClusterSpec{
+					KubernetesVersion: "v1.25.0",
+					CloudProvider: api.CloudProviderSpec{
+						Scaleway: &api.ScalewaySpec{},
+					},
+				},
+			},
+			architecture: architectures.ArchitectureAmd64,
+			expected:     defaultScalewayImage,
+		},
+	}
+
+	channel, err := api.LoadChannel("file://tests/channels/channel.yaml")
+	if err != nil {
+		t.Fatalf("unable to load test channel: %v", err)
+	}
+
+	for _, test := range tests {
+		actual, err := defaultImage(test.cluster, channel, test.architecture)
+		if err != nil {
+			t.Error(err)
+			continue
+		}
+		if actual != test.expected {
+			t.Errorf("unexpected default image for cluster %s: expected=%q, actual=%q", fi.DebugAsJsonString(test.cluster.Spec), test.expected, actual)
+		}
+	}
+}
