@@ -20,12 +20,13 @@ import (
 	"crypto/tls"
 	"fmt"
 	"net/http"
+	"os"
 	"strings"
 	"time"
 
 	"github.com/blang/semver/v4"
 	"github.com/gophercloud/gophercloud"
-	os "github.com/gophercloud/gophercloud/openstack"
+	"github.com/gophercloud/gophercloud/openstack"
 	cinder "github.com/gophercloud/gophercloud/openstack/blockstorage/v3/volumes"
 	az "github.com/gophercloud/gophercloud/openstack/compute/v2/extensions/availabilityzones"
 	"github.com/gophercloud/gophercloud/openstack/compute/v2/extensions/keypairs"
@@ -55,7 +56,6 @@ import (
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider/providers/openstack/designate"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/cloudinstances"
-	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/util/pkg/vfs"
 )
@@ -64,6 +64,7 @@ const (
 	TagNameEtcdClusterPrefix = "k8s.io/etcd/"
 	TagNameRolePrefix        = "k8s.io/role/"
 	TagClusterName           = "KubernetesCluster"
+	TagRoleControlPlane      = "control-plane"
 	TagRoleMaster            = "master"
 	TagKopsInstanceGroup     = "KopsInstanceGroup"
 	TagKopsNetwork           = "KopsNetwork"
@@ -320,7 +321,7 @@ var _ fi.Cloud = &openstackCloud{}
 
 var openstackCloudInstances = make(map[string]OpenstackCloud)
 
-func NewOpenstackCloud(tags map[string]string, spec *kops.ClusterSpec, uagent string) (OpenstackCloud, error) {
+func NewOpenstackCloud(cluster *kops.Cluster, uagent string) (OpenstackCloud, error) {
 	config := vfs.OpenstackConfig{}
 
 	region, err := config.GetRegion()
@@ -338,7 +339,7 @@ func NewOpenstackCloud(tags map[string]string, spec *kops.ClusterSpec, uagent st
 		return nil, err
 	}
 
-	provider, err := os.NewClient(authOption.IdentityEndpoint)
+	provider, err := openstack.NewClient(authOption.IdentityEndpoint)
 	if err != nil {
 		return nil, fmt.Errorf("error building openstack provider client: %v", err)
 	}
@@ -347,9 +348,9 @@ func NewOpenstackCloud(tags map[string]string, spec *kops.ClusterSpec, uagent st
 	provider.UserAgent = ua
 	klog.V(4).Infof("Using user-agent %s", ua.Join())
 
-	if spec != nil && spec.CloudProvider.Openstack != nil && spec.CloudProvider.Openstack.InsecureSkipVerify != nil {
+	if cluster != nil && cluster.Spec.CloudProvider.Openstack != nil && cluster.Spec.CloudProvider.Openstack.InsecureSkipVerify != nil {
 		tlsconfig := &tls.Config{}
-		tlsconfig.InsecureSkipVerify = fi.BoolValue(spec.CloudProvider.Openstack.InsecureSkipVerify)
+		tlsconfig.InsecureSkipVerify = fi.ValueOf(cluster.Spec.CloudProvider.Openstack.InsecureSkipVerify)
 		transport := &http.Transport{TLSClientConfig: tlsconfig}
 		provider.HTTPClient = http.Client{
 			Transport: transport,
@@ -358,56 +359,68 @@ func NewOpenstackCloud(tags map[string]string, spec *kops.ClusterSpec, uagent st
 
 	klog.V(2).Info("authenticating to keystone")
 
-	err = os.Authenticate(provider, authOption)
+	err = openstack.Authenticate(provider, authOption)
 	if err != nil {
 		return nil, fmt.Errorf("error building openstack authenticated client: %v", err)
 	}
 
-	cinderClient, err := os.NewBlockStorageV3(provider, gophercloud.EndpointOpts{
+	if cluster != nil {
+		hasDNS := !cluster.IsGossip() && !cluster.UsesNoneDNS()
+		tags := map[string]string{
+			TagClusterName: cluster.Name,
+		}
+		return buildClients(provider, tags, cluster.Spec.CloudProvider.Openstack, config, region, hasDNS)
+	}
+	// used by protokube
+	return buildClients(provider, nil, nil, config, region, false)
+}
+
+func buildClients(provider *gophercloud.ProviderClient, tags map[string]string, spec *kops.OpenstackSpec, config vfs.OpenstackConfig, region string, hasDNS bool) (OpenstackCloud, error) {
+	cinderClient, err := openstack.NewBlockStorageV3(provider, gophercloud.EndpointOpts{
 		Type:   "volumev3",
 		Region: region,
 	})
 	if err != nil {
-		return nil, fmt.Errorf("error building cinder client: %v", err)
+		return nil, fmt.Errorf("error building cinder client: %w", err)
 	}
 
-	neutronClient, err := os.NewNetworkV2(provider, gophercloud.EndpointOpts{
+	neutronClient, err := openstack.NewNetworkV2(provider, gophercloud.EndpointOpts{
 		Type:   "network",
 		Region: region,
 	})
 	if err != nil {
-		return nil, fmt.Errorf("error building neutron client: %v", err)
+		return nil, fmt.Errorf("error building neutron client: %w", err)
 	}
 
-	novaClient, err := os.NewComputeV2(provider, gophercloud.EndpointOpts{
+	novaClient, err := openstack.NewComputeV2(provider, gophercloud.EndpointOpts{
 		Type:   "compute",
 		Region: region,
 	})
 	if err != nil {
-		return nil, fmt.Errorf("error building nova client: %v", err)
+		return nil, fmt.Errorf("error building nova client: %w", err)
 	}
 	// 2.47 is the minimum version where the compute API /server/details returns flavor names
 	novaClient.Microversion = "2.47"
 
-	glanceClient, err := os.NewImageServiceV2(provider, gophercloud.EndpointOpts{
+	glanceClient, err := openstack.NewImageServiceV2(provider, gophercloud.EndpointOpts{
 		Type:   "image",
 		Region: region,
 	})
 	if err != nil {
-		return nil, fmt.Errorf("error building glance client: %v", err)
+		return nil, fmt.Errorf("error building glance client: %w", err)
 	}
 
 	var dnsClient *gophercloud.ServiceClient
-	if !dns.IsGossipHostname(tags[TagClusterName]) {
+	if hasDNS {
 		// TODO: This should be replaced with the environment variable methods as done above
 		endpointOpt, err := config.GetServiceConfig("Designate")
 		if err != nil {
-			return nil, err
+			return nil, fmt.Errorf("failed to get service config: %w", err)
 		}
 
-		dnsClient, err = os.NewDNSV2(provider, endpointOpt)
+		dnsClient, err = openstack.NewDNSV2(provider, endpointOpt)
 		if err != nil {
-			return nil, fmt.Errorf("error building dns client: %v", err)
+			return nil, fmt.Errorf("error building dns client: %w", err)
 		}
 	}
 
@@ -422,67 +435,79 @@ func NewOpenstackCloud(tags map[string]string, spec *kops.ClusterSpec, uagent st
 		useOctavia:    false,
 	}
 
-	octavia := false
-	floatingEnabled := false
-	if spec != nil &&
-		spec.CloudProvider.Openstack != nil &&
-		spec.CloudProvider.Openstack.Router != nil {
-
-		floatingEnabled = true
-		c.extNetworkName = spec.CloudProvider.Openstack.Router.ExternalNetwork
-
-		if spec.CloudProvider.Openstack.Router.ExternalSubnet != nil {
-			c.extSubnetName = spec.CloudProvider.Openstack.Router.ExternalSubnet
-		}
-		if spec.CloudProvider.Openstack.Loadbalancer != nil &&
-			spec.CloudProvider.Openstack.Loadbalancer.FloatingNetworkID == nil &&
-			spec.CloudProvider.Openstack.Loadbalancer.FloatingNetwork != nil {
-			// This field is derived
-			lbNet, err := c.ListNetworks(networks.ListOpts{
-				Name: fi.StringValue(spec.CloudProvider.Openstack.Loadbalancer.FloatingNetwork),
-			})
-			if err != nil || len(lbNet) != 1 {
-				return c, fmt.Errorf("could not establish floating network id")
-			}
-			spec.CloudProvider.Openstack.Loadbalancer.FloatingNetworkID = fi.String(lbNet[0].ID)
-		}
-		if spec.CloudProvider.Openstack.Loadbalancer != nil {
-			if spec.CloudProvider.Openstack.Loadbalancer.UseOctavia != nil {
-				octavia = fi.BoolValue(spec.CloudProvider.Openstack.Loadbalancer.UseOctavia)
-			}
-			if spec.CloudProvider.Openstack.Loadbalancer.FloatingSubnet != nil {
-				c.floatingSubnet = spec.CloudProvider.Openstack.Loadbalancer.FloatingSubnet
-			}
-		}
+	err = buildLoadBalancerClient(c, spec, provider, region)
+	if err != nil {
+		return nil, fmt.Errorf("failed to build load balancer client: %w", err)
 	}
-	c.floatingEnabled = floatingEnabled
-	c.useOctavia = octavia
-	var lbClient *gophercloud.ServiceClient
-	if spec != nil && spec.CloudProvider.Openstack != nil {
-		if spec.CloudProvider.Openstack.Loadbalancer != nil && octavia {
-			klog.V(2).Infof("Openstack using Octavia lbaasv2 api")
-			lbClient, err = os.NewLoadBalancerV2(provider, gophercloud.EndpointOpts{
-				Region: region,
-			})
-			if err != nil {
-				return nil, fmt.Errorf("error building lb client: %v", err)
-			}
-		} else if spec.CloudProvider.Openstack.Loadbalancer != nil {
-			klog.V(2).Infof("Openstack using deprecated lbaasv2 api")
-			lbClient, err = os.NewNetworkV2(provider, gophercloud.EndpointOpts{
-				Region: region,
-			})
-			if err != nil {
-				return nil, fmt.Errorf("error building lb client: %v", err)
-			}
-		} else {
-			klog.V(2).Infof("Openstack disabled loadbalancer support")
-		}
-	}
-	c.lbClient = lbClient
 	openstackCloudInstances[region] = c
 
 	return c, nil
+
+}
+
+func buildLoadBalancerClient(c *openstackCloud, spec *kops.OpenstackSpec, provider *gophercloud.ProviderClient, region string) error {
+
+	if spec == nil || spec.Loadbalancer == nil {
+		klog.V(2).Infof("Openstack disabled loadbalancer support")
+		return nil
+	}
+
+	octavia := false
+	floatingEnabled := false
+	if spec.Router != nil {
+
+		floatingEnabled = true
+		c.extNetworkName = spec.Router.ExternalNetwork
+
+		if spec.Router.ExternalSubnet != nil {
+			c.extSubnetName = spec.Router.ExternalSubnet
+		}
+		if spec.Loadbalancer.FloatingNetworkID == nil &&
+			spec.Loadbalancer.FloatingNetwork != nil {
+			// This field is derived
+			lbNet, err := c.ListNetworks(networks.ListOpts{
+				Name: fi.ValueOf(spec.Loadbalancer.FloatingNetwork),
+			})
+			if err != nil || len(lbNet) != 1 {
+				return fmt.Errorf("could not establish floating network id")
+			}
+			spec.Loadbalancer.FloatingNetworkID = fi.PtrTo(lbNet[0].ID)
+		}
+
+		if spec.Loadbalancer.UseOctavia != nil {
+			octavia = fi.ValueOf(spec.Loadbalancer.UseOctavia)
+		}
+		if spec.Loadbalancer.FloatingSubnet != nil {
+			c.floatingSubnet = spec.Loadbalancer.FloatingSubnet
+		}
+	} else if fi.ValueOf(spec.Loadbalancer.UseOctavia) {
+		return fmt.Errorf("cluster configured to use octavia, but router was not configured")
+	}
+	c.floatingEnabled = floatingEnabled
+	c.useOctavia = octavia
+
+	var lbClient *gophercloud.ServiceClient
+	if octavia {
+		klog.V(2).Infof("Openstack using Octavia lbaasv2 api")
+		client, err := openstack.NewLoadBalancerV2(provider, gophercloud.EndpointOpts{
+			Region: region,
+		})
+		if err != nil {
+			return fmt.Errorf("error building lb client: %w", err)
+		}
+		lbClient = client
+	} else {
+		klog.V(2).Infof("Openstack using deprecated lbaasv2 api")
+		client, err := openstack.NewNetworkV2(provider, gophercloud.EndpointOpts{
+			Region: region,
+		})
+		if err != nil {
+			return fmt.Errorf("error building lb client: %w", err)
+		}
+		lbClient = client
+	}
+	c.lbClient = lbClient
+	return nil
 }
 
 // UseZones add unique zone names to openstackcloud
@@ -655,6 +680,9 @@ func (c *openstackCloud) UseLoadBalancerVIPACL() (bool, error) {
 }
 
 func useLoadBalancerVIPACL(c OpenstackCloud) (bool, error) {
+	if c.LoadBalancerClient() == nil {
+		return false, nil
+	}
 	allPages, err := apiversions.List(c.LoadBalancerClient()).AllPages()
 	if err != nil {
 		return false, err
@@ -693,32 +721,35 @@ func getApiIngressStatus(c OpenstackCloud, cluster *kops.Cluster) ([]fi.ApiIngre
 
 func getLoadBalancerIngressStatus(c OpenstackCloud, cluster *kops.Cluster) ([]fi.ApiIngressStatus, error) {
 	var ingresses []fi.ApiIngressStatus
-	if cluster.Spec.MasterPublicName != "" {
-		// Note that this must match OpenstackModel lb name
-		klog.V(2).Infof("Querying Openstack to find Loadbalancers for API (%q)", cluster.Name)
-		lbList, err := c.ListLBs(loadbalancers.ListOpts{
-			Name: cluster.Spec.MasterPublicName,
+	lbName := "api." + cluster.Name
+	if cluster.Spec.API.PublicName != "" {
+		lbName = cluster.Spec.API.PublicName
+	}
+	// Note that this must match OpenstackModel lb name
+	klog.V(2).Infof("Querying Openstack to find Loadbalancers for API (%q)", cluster.Name)
+	lbList, err := c.ListLBs(loadbalancers.ListOpts{
+		Name: lbName,
+	})
+	if err != nil {
+		return ingresses, fmt.Errorf("GetApiIngressStatus: Failed to list openstack loadbalancers: %v", err)
+	}
+	for _, lb := range lbList {
+		// Must Find Floating IP related to this lb
+		fips, err := c.ListL3FloatingIPs(l3floatingip.ListOpts{
+			PortID: lb.VipPortID,
 		})
 		if err != nil {
-			return ingresses, fmt.Errorf("GetApiIngressStatus: Failed to list openstack loadbalancers: %v", err)
+			return ingresses, fmt.Errorf("GetApiIngressStatus: Failed to list floating IP's: %v", err)
 		}
-		for _, lb := range lbList {
-			// Must Find Floating IP related to this lb
-			fips, err := c.ListL3FloatingIPs(l3floatingip.ListOpts{
-				PortID: lb.VipPortID,
-			})
-			if err != nil {
-				return ingresses, fmt.Errorf("GetApiIngressStatus: Failed to list floating IP's: %v", err)
-			}
-			for _, fip := range fips {
-				if fip.PortID == lb.VipPortID {
-					ingresses = append(ingresses, fi.ApiIngressStatus{
-						IP: fip.FloatingIP,
-					})
-				}
+		for _, fip := range fips {
+			if fip.PortID == lb.VipPortID {
+				ingresses = append(ingresses, fi.ApiIngressStatus{
+					IP: fip.FloatingIP,
+				})
 			}
 		}
 	}
+
 	return ingresses, nil
 }
 
@@ -726,15 +757,15 @@ func getIPIngressStatus(c OpenstackCloud, cluster *kops.Cluster) (ingresses []fi
 	done, err := vfs.RetryWithBackoff(readBackoff, func() (bool, error) {
 		instances, err := c.ListInstances(servers.ListOpts{})
 		if err != nil {
-			return false, fmt.Errorf("GetApiIngressStatus: Failed to list master nodes: %v", err)
+			return false, fmt.Errorf("GetApiIngressStatus: Failed to list control plane nodes: %v", err)
 		}
 		for _, instance := range instances {
 			val, ok := instance.Metadata["k8s"]
 			val2, ok2 := instance.Metadata["KopsRole"]
 			if ok && val == cluster.Name && ok2 {
 				role, success := kops.ParseInstanceGroupRole(val2, false)
-				if success && role == kops.InstanceGroupRoleMaster {
-					if cluster.Spec.Topology != nil && cluster.Spec.Topology.Masters == kops.TopologyPrivate {
+				if success && role == kops.InstanceGroupRoleControlPlane {
+					if cluster.Spec.Networking.Topology != nil && cluster.Spec.Networking.Topology.ControlPlane == kops.TopologyPrivate {
 						ifName := instance.Metadata[TagKopsNetwork]
 						address, err := GetServerFixedIP(&instance, ifName)
 						if err != nil {
@@ -750,7 +781,7 @@ func getIPIngressStatus(c OpenstackCloud, cluster *kops.Cluster) (ingresses []fi
 						}
 						for _, ip := range ips {
 							ingresses = append(ingresses, fi.ApiIngressStatus{
-								IP: fi.StringValue(ip),
+								IP: fi.ValueOf(ip),
 							})
 						}
 					}
@@ -786,3 +817,105 @@ func isNotFound(err error) bool {
 
 	return false
 }
+
+func MakeCloudConfig(spec kops.ClusterSpec) []string {
+	var lines []string
+
+	osc := spec.CloudProvider.Openstack
+	if osc == nil {
+		return nil
+	}
+
+	// Support mapping of older keystone API
+	tenantName := os.Getenv("OS_TENANT_NAME")
+	if tenantName == "" {
+		tenantName = os.Getenv("OS_PROJECT_NAME")
+	}
+	tenantID := os.Getenv("OS_TENANT_ID")
+	if tenantID == "" {
+		tenantID = os.Getenv("OS_PROJECT_ID")
+	}
+	lines = append(lines,
+		fmt.Sprintf("auth-url=\"%s\"", os.Getenv("OS_AUTH_URL")),
+		fmt.Sprintf("username=\"%s\"", os.Getenv("OS_USERNAME")),
+		fmt.Sprintf("password=\"%s\"", os.Getenv("OS_PASSWORD")),
+		fmt.Sprintf("region=\"%s\"", os.Getenv("OS_REGION_NAME")),
+		fmt.Sprintf("tenant-id=\"%s\"", tenantID),
+		fmt.Sprintf("tenant-name=\"%s\"", tenantName),
+		fmt.Sprintf("domain-name=\"%s\"", os.Getenv("OS_DOMAIN_NAME")),
+		fmt.Sprintf("domain-id=\"%s\"", os.Getenv("OS_DOMAIN_ID")),
+	)
+	if spec.ExternalCloudControllerManager != nil {
+		lines = append(lines,
+			fmt.Sprintf("application-credential-id=\"%s\"", os.Getenv("OS_APPLICATION_CREDENTIAL_ID")),
+			fmt.Sprintf("application-credential-secret=\"%s\"", os.Getenv("OS_APPLICATION_CREDENTIAL_SECRET")),
+		)
+	}
+
+	lines = append(lines,
+		"",
+	)
+
+	if lb := osc.Loadbalancer; lb != nil {
+		ingressHostnameSuffix := "nip.io"
+		if fi.ValueOf(lb.IngressHostnameSuffix) != "" {
+			ingressHostnameSuffix = fi.ValueOf(lb.IngressHostnameSuffix)
+		}
+
+		lines = append(lines,
+			"[LoadBalancer]",
+			fmt.Sprintf("floating-network-id=%s", fi.ValueOf(lb.FloatingNetworkID)),
+			fmt.Sprintf("lb-method=%s", fi.ValueOf(lb.Method)),
+			fmt.Sprintf("lb-provider=%s", fi.ValueOf(lb.Provider)),
+			fmt.Sprintf("use-octavia=%t", fi.ValueOf(lb.UseOctavia)),
+			fmt.Sprintf("manage-security-groups=%t", fi.ValueOf(lb.ManageSecGroups)),
+			fmt.Sprintf("enable-ingress-hostname=%t", fi.ValueOf(lb.EnableIngressHostname)),
+			fmt.Sprintf("ingress-hostname-suffix=%s", ingressHostnameSuffix),
+			"",
+		)
+
+		if monitor := osc.Monitor; monitor != nil {
+			lines = append(lines,
+				"create-monitor=yes",
+				fmt.Sprintf("monitor-delay=%s", fi.ValueOf(monitor.Delay)),
+				fmt.Sprintf("monitor-timeout=%s", fi.ValueOf(monitor.Timeout)),
+				fmt.Sprintf("monitor-max-retries=%d", fi.ValueOf(monitor.MaxRetries)),
+				"",
+			)
+		}
+	}
+
+	if bs := osc.BlockStorage; bs != nil {
+		// Block Storage Config
+		lines = append(lines,
+			"[BlockStorage]",
+			fmt.Sprintf("bs-version=%s", fi.ValueOf(bs.Version)),
+			fmt.Sprintf("ignore-volume-az=%t", fi.ValueOf(bs.IgnoreAZ)),
+			fmt.Sprintf("ignore-volume-microversion=%t", fi.ValueOf(bs.IgnoreVolumeMicroVersion)),
+			"")
+	}
+
+	if networking := osc.Network; networking != nil {
+		// Networking Config
+		// https://github.com/kubernetes/cloud-provider-openstack/blob/master/docs/openstack-cloud-controller-manager/using-openstack-cloud-controller-manager.md#networking
+		var networkingLines []string
+
+		if networking.IPv6SupportDisabled != nil {
+			networkingLines = append(networkingLines, fmt.Sprintf("ipv6-support-disabled=%t", fi.ValueOf(networking.IPv6SupportDisabled)))
+		}
+		for _, name := range networking.PublicNetworkNames {
+			networkingLines = append(networkingLines, fmt.Sprintf("public-network-name=%s", fi.ValueOf(name)))
+		}
+		for _, name := range networking.InternalNetworkNames {
+			networkingLines = append(networkingLines, fmt.Sprintf("internal-network-name=%s", fi.ValueOf(name)))
+		}
+
+		if len(networkingLines) > 0 {
+			lines = append(lines, "[Networking]")
+			lines = append(lines, networkingLines...)
+			lines = append(lines, "")
+		}
+	}
+
+	return lines
+}
