@@ -59,17 +59,17 @@ type LaunchSpec struct {
 }
 
 var (
-	_ fi.Task            = &LaunchSpec{}
-	_ fi.CompareWithID   = &LaunchSpec{}
-	_ fi.HasDependencies = &LaunchSpec{}
+	_ fi.CloudupTask            = &LaunchSpec{}
+	_ fi.CompareWithID          = &LaunchSpec{}
+	_ fi.CloudupHasDependencies = &LaunchSpec{}
 )
 
 func (o *LaunchSpec) CompareWithID() *string {
 	return o.Name
 }
 
-func (o *LaunchSpec) GetDependencies(tasks map[string]fi.Task) []fi.Task {
-	var deps []fi.Task
+func (o *LaunchSpec) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
+	var deps []fi.CloudupTask
 
 	if o.IAMInstanceProfile != nil {
 		deps = append(deps, o.IAMInstanceProfile)
@@ -99,11 +99,11 @@ func (o *LaunchSpec) GetDependencies(tasks map[string]fi.Task) []fi.Task {
 }
 
 func (o *LaunchSpec) find(svc spotinst.LaunchSpecService, oceanID string) (*aws.LaunchSpec, error) {
-	klog.V(4).Infof("Attempting to find LaunchSpec: %q", fi.StringValue(o.Name))
+	klog.V(4).Infof("Attempting to find LaunchSpec: %q", fi.ValueOf(o.Name))
 
 	specs, err := svc.List(context.Background(), oceanID)
 	if err != nil {
-		return nil, fmt.Errorf("spotinst: failed to find launch spec %q: %v", fi.StringValue(o.Name), err)
+		return nil, fmt.Errorf("spotinst: failed to find launch spec %q: %v", fi.ValueOf(o.Name), err)
 	}
 	if len(specs) == 0 {
 		return nil, fmt.Errorf("spotinst: no launch specs associated with ocean %q", oceanID)
@@ -111,23 +111,23 @@ func (o *LaunchSpec) find(svc spotinst.LaunchSpecService, oceanID string) (*aws.
 
 	var out *aws.LaunchSpec
 	for _, spec := range specs {
-		if spec.Name() == fi.StringValue(o.Name) {
+		if spec.Name() == fi.ValueOf(o.Name) {
 			out = spec.Obj().(*aws.LaunchSpec)
 			break
 		}
 	}
 	if out == nil {
-		return nil, fmt.Errorf("spotinst: failed to find launch spec %q", fi.StringValue(o.Name))
+		return nil, fmt.Errorf("spotinst: failed to find launch spec %q", fi.ValueOf(o.Name))
 	}
 
-	klog.V(4).Infof("LaunchSpec/%s: %s", fi.StringValue(o.Name), stringutil.Stringify(out))
+	klog.V(4).Infof("LaunchSpec/%s: %s", fi.ValueOf(o.Name), stringutil.Stringify(out))
 	return out, nil
 }
 
-var _ fi.HasCheckExisting = &LaunchSpec{}
+var _ fi.CloudupHasCheckExisting = &LaunchSpec{}
 
-func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (o *LaunchSpec) Find(c *fi.CloudupContext) (*LaunchSpec, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	ocean, err := o.Ocean.find(cloud.Spotinst().Ocean())
 	if err != nil {
@@ -149,8 +149,8 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 	// Capacity.
 	{
 		if spec.ResourceLimits != nil {
-			actual.MinSize = fi.Int64(int64(fi.IntValue(spec.ResourceLimits.MinInstanceCount)))
-			actual.MaxSize = fi.Int64(int64(fi.IntValue(spec.ResourceLimits.MaxInstanceCount)))
+			actual.MinSize = fi.PtrTo(int64(fi.ValueOf(spec.ResourceLimits.MinInstanceCount)))
+			actual.MaxSize = fi.PtrTo(int64(fi.ValueOf(spec.ResourceLimits.MaxInstanceCount)))
 		}
 	}
 
@@ -159,12 +159,12 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		actual.ImageID = spec.ImageID
 
 		if o.ImageID != nil && actual.ImageID != nil &&
-			fi.StringValue(actual.ImageID) != fi.StringValue(o.ImageID) {
-			image, err := resolveImage(cloud, fi.StringValue(o.ImageID))
+			fi.ValueOf(actual.ImageID) != fi.ValueOf(o.ImageID) {
+			image, err := resolveImage(cloud, fi.ValueOf(o.ImageID))
 			if err != nil {
 				return nil, err
 			}
-			if fi.StringValue(image.ImageId) == fi.StringValue(spec.ImageID) {
+			if fi.ValueOf(image.ImageId) == fi.ValueOf(spec.ImageID) {
 				actual.ImageID = o.ImageID
 			}
 		}
@@ -173,7 +173,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 	// User data.
 	{
 		if spec.UserData != nil {
-			userData, err := base64.StdEncoding.DecodeString(fi.StringValue(spec.UserData))
+			userData, err := base64.StdEncoding.DecodeString(fi.ValueOf(spec.UserData))
 			if err != nil {
 				return nil, err
 			}
@@ -194,7 +194,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		{
 			if spec.RootVolumeSize != nil {
 				actual.RootVolumeOpts = new(RootVolumeOpts)
-				actual.RootVolumeOpts.Size = fi.Int64(int64(*spec.RootVolumeSize))
+				actual.RootVolumeOpts.Size = fi.PtrTo(int64(*spec.RootVolumeSize))
 			}
 		}
 
@@ -209,16 +209,16 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 						actual.RootVolumeOpts = new(RootVolumeOpts)
 					}
 					if b.EBS.VolumeType != nil {
-						actual.RootVolumeOpts.Type = fi.String(strings.ToLower(fi.StringValue(b.EBS.VolumeType)))
+						actual.RootVolumeOpts.Type = fi.PtrTo(strings.ToLower(fi.ValueOf(b.EBS.VolumeType)))
 					}
 					if b.EBS.VolumeSize != nil {
-						actual.RootVolumeOpts.Size = fi.Int64(int64(fi.IntValue(b.EBS.VolumeSize)))
+						actual.RootVolumeOpts.Size = fi.PtrTo(int64(fi.ValueOf(b.EBS.VolumeSize)))
 					}
 					if b.EBS.IOPS != nil {
-						actual.RootVolumeOpts.IOPS = fi.Int64(int64(fi.IntValue(b.EBS.IOPS)))
+						actual.RootVolumeOpts.IOPS = fi.PtrTo(int64(fi.ValueOf(b.EBS.IOPS)))
 					}
 					if b.EBS.Throughput != nil {
-						actual.RootVolumeOpts.Throughput = fi.Int64(int64(fi.IntValue(b.EBS.Throughput)))
+						actual.RootVolumeOpts.Throughput = fi.PtrTo(int64(fi.ValueOf(b.EBS.Throughput)))
 					}
 					if b.EBS.Encrypted != nil {
 						actual.RootVolumeOpts.Encryption = b.EBS.Encrypted
@@ -233,7 +233,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		if spec.SecurityGroupIDs != nil {
 			for _, sgID := range spec.SecurityGroupIDs {
 				actual.SecurityGroups = append(actual.SecurityGroups,
-					&awstasks.SecurityGroup{ID: fi.String(sgID)})
+					&awstasks.SecurityGroup{ID: fi.PtrTo(sgID)})
 			}
 		}
 	}
@@ -243,7 +243,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		if spec.SubnetIDs != nil {
 			for _, subnetID := range spec.SubnetIDs {
 				actual.Subnets = append(actual.Subnets,
-					&awstasks.Subnet{ID: fi.String(subnetID)})
+					&awstasks.Subnet{ID: fi.PtrTo(subnetID)})
 			}
 			if subnetSlicesEqualIgnoreOrder(actual.Subnets, o.Subnets) {
 				actual.Subnets = o.Subnets
@@ -268,7 +268,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		if len(spec.Tags) > 0 {
 			actual.Tags = make(map[string]string)
 			for _, tag := range spec.Tags {
-				actual.Tags[fi.StringValue(tag.Key)] = fi.StringValue(tag.Value)
+				actual.Tags[fi.ValueOf(tag.Key)] = fi.ValueOf(tag.Value)
 			}
 		}
 	}
@@ -298,7 +298,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 
 		actual.AutoScalerOpts.Labels = make(map[string]string)
 		for _, label := range spec.Labels {
-			actual.AutoScalerOpts.Labels[fi.StringValue(label.Key)] = fi.StringValue(label.Value)
+			actual.AutoScalerOpts.Labels[fi.ValueOf(label.Key)] = fi.ValueOf(label.Value)
 		}
 	}
 
@@ -311,9 +311,9 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 		actual.AutoScalerOpts.Taints = make([]*corev1.Taint, len(spec.Taints))
 		for i, taint := range spec.Taints {
 			actual.AutoScalerOpts.Taints[i] = &corev1.Taint{
-				Key:    fi.StringValue(taint.Key),
-				Value:  fi.StringValue(taint.Value),
-				Effect: corev1.TaintEffect(fi.StringValue(taint.Effect)),
+				Key:    fi.ValueOf(taint.Key),
+				Value:  fi.ValueOf(taint.Value),
+				Effect: corev1.TaintEffect(fi.ValueOf(taint.Effect)),
 			}
 		}
 	}
@@ -322,7 +322,7 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 	{
 		if strategy := spec.Strategy; strategy != nil {
 			if strategy.SpotPercentage != nil {
-				actual.SpotPercentage = fi.Int64(int64(fi.IntValue(strategy.SpotPercentage)))
+				actual.SpotPercentage = fi.PtrTo(int64(fi.ValueOf(strategy.SpotPercentage)))
 			}
 		}
 	}
@@ -333,13 +333,13 @@ func (o *LaunchSpec) Find(c *fi.Context) (*LaunchSpec, error) {
 	return actual, nil
 }
 
-func (o *LaunchSpec) CheckExisting(c *fi.Context) bool {
+func (o *LaunchSpec) CheckExisting(c *fi.CloudupContext) bool {
 	spec, err := o.Find(c)
 	return err == nil && spec != nil
 }
 
-func (o *LaunchSpec) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(o, c)
+func (o *LaunchSpec) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(o, c)
 }
 
 func (s *LaunchSpec) CheckChanges(a, e, changes *LaunchSpec) error {
@@ -380,15 +380,15 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 	{
 		if e.MinSize != nil || e.MaxSize != nil {
 			spec.ResourceLimits = new(aws.ResourceLimits)
-			spec.ResourceLimits.SetMinInstanceCount(fi.Int(int(*e.MinSize)))
-			spec.ResourceLimits.SetMaxInstanceCount(fi.Int(int(*e.MaxSize)))
+			spec.ResourceLimits.SetMinInstanceCount(fi.PtrTo(int(*e.MinSize)))
+			spec.ResourceLimits.SetMaxInstanceCount(fi.PtrTo(int(*e.MaxSize)))
 		}
 	}
 
 	// Image.
 	{
 		if e.ImageID != nil {
-			image, err := resolveImage(cloud, fi.StringValue(e.ImageID))
+			image, err := resolveImage(cloud, fi.ValueOf(e.ImageID))
 			if err != nil {
 				return err
 			}
@@ -406,7 +406,7 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 
 			if len(userData) > 0 {
 				encoded := base64.StdEncoding.EncodeToString([]byte(userData))
-				spec.SetUserData(fi.String(encoded))
+				spec.SetUserData(fi.PtrTo(encoded))
 			}
 		}
 	}
@@ -450,7 +450,7 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 		if e.Subnets != nil {
 			subnetIDs := make([]string, len(e.Subnets))
 			for i, subnet := range e.Subnets {
-				subnetIDs[i] = fi.StringValue(subnet.ID)
+				subnetIDs[i] = fi.ValueOf(subnet.ID)
 			}
 			spec.SetSubnetIDs(subnetIDs)
 		}
@@ -499,8 +499,8 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				var labels []*aws.Label
 				for k, v := range opts.Labels {
 					labels = append(labels, &aws.Label{
-						Key:   fi.String(k),
-						Value: fi.String(v),
+						Key:   fi.PtrTo(k),
+						Value: fi.PtrTo(v),
 					})
 				}
 				spec.SetLabels(labels)
@@ -511,9 +511,9 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				taints := make([]*aws.Taint, len(opts.Taints))
 				for i, taint := range opts.Taints {
 					taints[i] = &aws.Taint{
-						Key:    fi.String(taint.Key),
-						Value:  fi.String(taint.Value),
-						Effect: fi.String(string(taint.Effect)),
+						Key:    fi.PtrTo(taint.Key),
+						Value:  fi.PtrTo(taint.Value),
+						Effect: fi.PtrTo(string(taint.Effect)),
 					}
 				}
 				spec.SetTaints(taints)
@@ -524,13 +524,13 @@ func (_ *LaunchSpec) create(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 	// Strategy.
 	{
 		if e.SpotPercentage != nil {
-			spec.Strategy.SetSpotPercentage(fi.Int(int(*e.SpotPercentage)))
+			spec.Strategy.SetSpotPercentage(fi.PtrTo(int(*e.SpotPercentage)))
 		}
 	}
 
 	// Restrictions.
 	{
-		if fi.BoolValue(e.RestrictScaleDown) {
+		if fi.ValueOf(e.RestrictScaleDown) {
 			spec.SetRestrictScaleDown(e.RestrictScaleDown)
 		}
 	}
@@ -576,7 +576,7 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				spec.ResourceLimits = new(aws.ResourceLimits)
 			}
 
-			spec.ResourceLimits.SetMinInstanceCount(fi.Int(int(*e.MinSize)))
+			spec.ResourceLimits.SetMinInstanceCount(fi.PtrTo(int(*e.MinSize)))
 			changes.MinSize = nil
 			changed = true
 		}
@@ -585,7 +585,7 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				spec.ResourceLimits = new(aws.ResourceLimits)
 			}
 
-			spec.ResourceLimits.SetMaxInstanceCount(fi.Int(int(*e.MaxSize)))
+			spec.ResourceLimits.SetMaxInstanceCount(fi.PtrTo(int(*e.MaxSize)))
 			changes.MaxSize = nil
 			changed = true
 		}
@@ -594,12 +594,12 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 	// Image.
 	{
 		if changes.ImageID != nil {
-			image, err := resolveImage(cloud, fi.StringValue(e.ImageID))
+			image, err := resolveImage(cloud, fi.ValueOf(e.ImageID))
 			if err != nil {
 				return err
 			}
 
-			if fi.StringValue(actual.ImageID) != fi.StringValue(image.ImageId) {
+			if fi.ValueOf(actual.ImageID) != fi.ValueOf(image.ImageId) {
 				spec.SetImageId(image.ImageId)
 			}
 
@@ -618,7 +618,7 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 
 			if len(userData) > 0 {
 				encoded := base64.StdEncoding.EncodeToString([]byte(userData))
-				spec.SetUserData(fi.String(encoded))
+				spec.SetUserData(fi.PtrTo(encoded))
 				changed = true
 			}
 
@@ -674,7 +674,7 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 		if changes.Subnets != nil {
 			subnetIDs := make([]string, len(e.Subnets))
 			for i, subnet := range e.Subnets {
-				subnetIDs[i] = fi.StringValue(subnet.ID)
+				subnetIDs[i] = fi.ValueOf(subnet.ID)
 			}
 
 			spec.SetSubnetIDs(subnetIDs)
@@ -735,8 +735,8 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				labels := make([]*aws.Label, 0, len(e.AutoScalerOpts.Labels))
 				for k, v := range e.AutoScalerOpts.Labels {
 					labels = append(labels, &aws.Label{
-						Key:   fi.String(k),
-						Value: fi.String(v),
+						Key:   fi.PtrTo(k),
+						Value: fi.PtrTo(v),
 					})
 				}
 
@@ -750,9 +750,9 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				taints := make([]*aws.Taint, 0, len(e.AutoScalerOpts.Taints))
 				for _, taint := range e.AutoScalerOpts.Taints {
 					taints = append(taints, &aws.Taint{
-						Key:    fi.String(taint.Key),
-						Value:  fi.String(taint.Value),
-						Effect: fi.String(string(taint.Effect)),
+						Key:    fi.PtrTo(taint.Key),
+						Value:  fi.PtrTo(taint.Value),
+						Effect: fi.PtrTo(string(taint.Effect)),
 					})
 				}
 
@@ -773,7 +773,7 @@ func (_ *LaunchSpec) update(cloud awsup.AWSCloud, a, e, changes *LaunchSpec) err
 				spec.Strategy = new(aws.LaunchSpecStrategy)
 			}
 
-			spec.Strategy.SetSpotPercentage(fi.Int(int(fi.Int64Value(e.SpotPercentage))))
+			spec.Strategy.SetSpotPercentage(fi.PtrTo(int(fi.ValueOf(e.SpotPercentage))))
 			changes.SpotPercentage = nil
 			changed = true
 		}
@@ -906,7 +906,7 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 	// Image.
 	{
 		if e.ImageID != nil {
-			image, err := resolveImage(cloud, fi.StringValue(e.ImageID))
+			image, err := resolveImage(cloud, fi.ValueOf(e.ImageID))
 			if err != nil {
 				return err
 			}
@@ -918,6 +918,9 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 	for key := range e.Ocean.Tags {
 		if strings.HasPrefix(key, awstasks.CloudTagInstanceGroupRolePrefix) {
 			suffix := strings.TrimPrefix(key, awstasks.CloudTagInstanceGroupRolePrefix)
+			if role == "master" {
+				role = "control-plane"
+			}
 			if role != "" && role != suffix {
 				return fmt.Errorf("spotinst: found multiple role tags %q vs %q", role, suffix)
 			}
@@ -986,7 +989,7 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 				VolumeIOPS:          rootDevice.EbsVolumeIops,
 				VolumeThroughput:    rootDevice.EbsVolumeThroughput,
 				Encrypted:           rootDevice.EbsEncrypted,
-				DeleteOnTermination: fi.Bool(true),
+				DeleteOnTermination: fi.PtrTo(true),
 			},
 		})
 	}
@@ -1023,8 +1026,8 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 				tf.Labels = make([]*terraformKV, 0, len(opts.Labels))
 				for k, v := range opts.Labels {
 					tf.Labels = append(tf.Labels, &terraformKV{
-						Key:   fi.String(k),
-						Value: fi.String(v),
+						Key:   fi.PtrTo(k),
+						Value: fi.PtrTo(v),
 					})
 				}
 			}
@@ -1034,11 +1037,11 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 				tf.Taints = make([]*terraformTaint, len(opts.Taints))
 				for i, taint := range opts.Taints {
 					t := &terraformTaint{
-						Key:    fi.String(taint.Key),
-						Effect: fi.String(string(taint.Effect)),
+						Key:    fi.PtrTo(taint.Key),
+						Effect: fi.PtrTo(string(taint.Effect)),
 					}
 					if taint.Value != "" {
-						t.Value = fi.String(taint.Value)
+						t.Value = fi.PtrTo(taint.Value)
 					}
 					tf.Taints[i] = t
 				}
@@ -1057,7 +1060,7 @@ func (_ *LaunchSpec) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 
 	// Restrictions.
 	{
-		if fi.BoolValue(e.RestrictScaleDown) {
+		if fi.ValueOf(e.RestrictScaleDown) {
 			tf.RestrictScaleDown = e.RestrictScaleDown
 		}
 	}
@@ -1074,8 +1077,8 @@ func (o *LaunchSpec) buildTags() []*aws.Tag {
 
 	for key, value := range o.Tags {
 		tags = append(tags, &aws.Tag{
-			Key:   fi.String(key),
-			Value: fi.String(value),
+			Key:   fi.PtrTo(key),
+			Value: fi.PtrTo(value),
 		})
 	}
 
@@ -1091,18 +1094,18 @@ func (o *LaunchSpec) convertBlockDeviceMapping(in *awstasks.BlockDeviceMapping)
 	if in.EbsDeleteOnTermination != nil || in.EbsVolumeSize != nil || in.EbsVolumeType != nil {
 		out.EBS = &aws.EBS{
 			VolumeType:          in.EbsVolumeType,
-			VolumeSize:          fi.Int(int(fi.Int64Value(in.EbsVolumeSize))),
+			VolumeSize:          fi.PtrTo(int(fi.ValueOf(in.EbsVolumeSize))),
 			DeleteOnTermination: in.EbsDeleteOnTermination,
 		}
 
 		// IOPS is not valid for gp2 volumes.
-		if in.EbsVolumeIops != nil && fi.StringValue(in.EbsVolumeType) != "gp2" {
-			out.EBS.IOPS = fi.Int(int(fi.Int64Value(in.EbsVolumeIops)))
+		if in.EbsVolumeIops != nil && fi.ValueOf(in.EbsVolumeType) != "gp2" {
+			out.EBS.IOPS = fi.PtrTo(int(fi.ValueOf(in.EbsVolumeIops)))
 		}
 
 		// Throughput is only valid for gp3 volumes.
-		if in.EbsVolumeThroughput != nil && fi.StringValue(in.EbsVolumeType) == "gp3" {
-			out.EBS.Throughput = fi.Int(int(fi.Int64Value(in.EbsVolumeThroughput)))
+		if in.EbsVolumeThroughput != nil && fi.ValueOf(in.EbsVolumeType) == "gp3" {
+			out.EBS.Throughput = fi.PtrTo(int(fi.ValueOf(in.EbsVolumeThroughput)))
 		}
 	}
 
