@@ -813,14 +813,12 @@ func (tf *TemplateFunctions) OpenStackCCMTag() string {
 	if err != nil {
 		tag = "latest"
 	} else {
-		if parsed.Minor == 23 {
-			tag = "v1.23.1"
-		} else if parsed.Minor == 24 {
+		if parsed.Minor == 24 {
 			tag = "v1.24.6"
 		} else if parsed.Minor == 25 {
-			tag = "v1.25.4"
+			tag = "v1.25.5"
 		} else if parsed.Minor == 26 {
-			tag = "v1.26.1"
+			tag = "v1.26.2"
 		} else {
 			// otherwise we use always .0 ccm image, if needed that can be overrided using clusterspec
 			tag = fmt.Sprintf("v%d.%d.0", parsed.Major, parsed.Minor)
@@ -840,9 +838,9 @@ func (tf *TemplateFunctions) OpenStackCSITag() string {
 		if parsed.Minor == 24 {
 			tag = "v1.24.6"
 		} else if parsed.Minor == 25 {
-			tag = "v1.25.4"
+			tag = "v1.25.5"
 		} else if parsed.Minor == 26 {
-			tag = "v1.26.1"
+			tag = "v1.26.2"
 		} else {
 			// otherwise we use always .0 csi image, if needed that can be overrided using cloud config spec
 			tag = fmt.Sprintf("v%d.%d.0", parsed.Major, parsed.Minor)
