@@ -17,6 +17,7 @@ limitations under the License.
 package cloudup
 
 import (
+	"context"
 	"fmt"
 	"strings"
 	"testing"
@@ -30,6 +31,7 @@ import (
 const testAWSRegion = "us-test-1"
 
 func buildDefaultCluster(t *testing.T) *api.Cluster {
+	ctx := context.TODO()
 	cloud, c := buildMinimalCluster()
 
 	err := PerformAssignments(c, cloud)
@@ -37,7 +39,7 @@ func buildDefaultCluster(t *testing.T) *api.Cluster {
 		t.Fatalf("error from PerformAssignments: %v", err)
 	}
 
-	fullSpec, err := mockedPopulateClusterSpec(c, cloud)
+	fullSpec, err := mockedPopulateClusterSpec(ctx, c, cloud)
 	if err != nil {
 		t.Fatalf("error from PopulateClusterSpec: %v", err)
 	}
@@ -121,11 +123,11 @@ func TestValidateFull_UpdatePolicy_Valid(t *testing.T) {
 		},
 		{
 			label:  "automatic",
-			policy: fi.String(api.UpdatePolicyAutomatic),
+			policy: fi.PtrTo(api.UpdatePolicyAutomatic),
 		},
 		{
 			label:  "external",
-			policy: fi.String(api.UpdatePolicyExternal),
+			policy: fi.PtrTo(api.UpdatePolicyExternal),
 		},
 	} {
 		t.Run(test.label, func(t *testing.T) {
@@ -160,9 +162,7 @@ func TestValidateFull_UpdatePolicy_Invalid(t *testing.T) {
 func Test_Validate_Kubenet_With_14(t *testing.T) {
 	c := buildDefaultCluster(t)
 	c.Spec.KubernetesVersion = "1.4.1"
-	c.Spec.Networking = &api.NetworkingSpec{
-		Kubenet: &api.KubenetNetworkingSpec{},
-	}
+	c.Spec.Networking.Kubenet = &api.KubenetNetworkingSpec{}
 
 	expectNoErrorFromValidate(t, c)
 }
