@@ -37,9 +37,9 @@ import (
 	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/kms"
+	"go.uber.org/multierr"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/nodeup/pkg/model"
-	"k8s.io/kops/nodeup/pkg/model/dns"
 	"k8s.io/kops/nodeup/pkg/model/networking"
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/registry"
@@ -48,12 +48,14 @@ import (
 	"k8s.io/kops/pkg/bootstrap"
 	"k8s.io/kops/pkg/configserver"
 	"k8s.io/kops/pkg/kopscodecs"
+	"k8s.io/kops/pkg/kopscontrollerclient"
 	"k8s.io/kops/pkg/resolver"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce/gcediscovery"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm/gcetpmsigner"
-	"k8s.io/kops/upup/pkg/fi/nodeup/cloudinit"
+	"k8s.io/kops/upup/pkg/fi/cloudup/hetzner"
+	"k8s.io/kops/upup/pkg/fi/cloudup/openstack"
 	"k8s.io/kops/upup/pkg/fi/nodeup/local"
 	"k8s.io/kops/upup/pkg/fi/nodeup/nodetasks"
 	"k8s.io/kops/upup/pkg/fi/secrets"
@@ -71,7 +73,8 @@ type NodeUpCommand struct {
 	CacheDir       string
 	ConfigLocation string
 	Target         string
-	cluster        *api.Cluster
+	// Deprecated: Fields should be accessed from NodeupConfig or BootConfig.
+	cluster *api.Cluster
 }
 
 // Run is responsible for perform the nodeup process
@@ -110,13 +113,13 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	// If we're using a config server instead of vfs, nodeConfig will hold our configuration
 	var nodeConfig *nodeup.NodeConfig
 
-	if bootConfig.ConfigServer != nil {
-		response, err := getNodeConfigFromServer(ctx, &bootConfig, region)
+	if bootConfig.ConfigServer != nil && len(bootConfig.ConfigServer.Servers) > 0 {
+		response, err := getNodeConfigFromServers(ctx, &bootConfig, region)
 		if err != nil {
 			return fmt.Errorf("failed to get node config from server: %w", err)
 		}
 		nodeConfig = response.NodeConfig
-	} else if fi.StringValue(bootConfig.ConfigBase) != "" {
+	} else if fi.ValueOf(bootConfig.ConfigBase) != "" {
 		var err error
 		configBase, err = vfs.Context.BuildVfsPath(*bootConfig.ConfigBase)
 		if err != nil {
@@ -162,7 +165,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 		nodeupConfigHash = sha256.Sum256([]byte(nodeConfig.NodeupConfig))
 		nodeupConfig.CAs[fi.CertificateIDCA] = bootConfig.ConfigServer.CACertificates
 	} else if bootConfig.InstanceGroupName != "" {
-		nodeupConfigLocation := configBase.Join("igconfig", strings.ToLower(string(bootConfig.InstanceGroupRole)), bootConfig.InstanceGroupName, "nodeupconfig.yaml")
+		nodeupConfigLocation := configBase.Join("igconfig", bootConfig.InstanceGroupRole.ToLowerString(), bootConfig.InstanceGroupName, "nodeupconfig.yaml")
 
 		b, err := nodeupConfigLocation.ReadFile()
 		if err != nil {
@@ -181,7 +184,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 		return fmt.Errorf("nodeup config hash mismatch (was %q, expected %q)", got, want)
 	}
 
-	cloudProvider := api.CloudProviderID(bootConfig.CloudProvider)
+	cloudProvider := bootConfig.CloudProvider
 	if cloudProvider == "" {
 		cloudProvider = c.cluster.Spec.GetCloudProvider()
 	}
@@ -233,9 +236,9 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 
 	var secretStore fi.SecretStore
-	var keyStore fi.Keystore
+	var keyStore fi.KeystoreReader
 	if nodeConfig != nil {
-		modelContext.SecretStore = configserver.NewSecretStore(nodeConfig)
+		modelContext.SecretStore = configserver.NewSecretStore(nodeConfig.NodeSecrets)
 	} else if c.cluster.Spec.SecretStore != "" {
 		klog.Infof("Building SecretStore at %q", c.cluster.Spec.SecretStore)
 		p, err := vfs.Context.BuildVfsPath(c.cluster.Spec.SecretStore)
@@ -287,7 +290,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 
 		// If Nvidia is enabled in the cluster, check if this instance has support for it.
 		nvidia := c.cluster.Spec.Containerd.NvidiaGPU
-		if nvidia != nil && fi.BoolValue(nvidia.Enabled) {
+		if nvidia != nil && fi.ValueOf(nvidia.Enabled) {
 			awsCloud := cloud.(awsup.AWSCloud)
 			// Get the instance type's detailed information.
 			instanceType, err := awsup.GetMachineTypeInfo(awsCloud, modelContext.MachineType)
@@ -302,7 +305,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 		}
 	} else if cloudProvider == api.CloudProviderOpenstack {
 		// NvidiaGPU possible to enable only in instance group level in OpenStack. When we assume that GPU is supported
-		if nodeupConfig.NvidiaGPU != nil && fi.BoolValue(nodeupConfig.NvidiaGPU.Enabled) {
+		if nodeupConfig.NvidiaGPU != nil && fi.ValueOf(nodeupConfig.NvidiaGPU.Enabled) {
 			klog.Info("instance supports GPU acceleration")
 			modelContext.GPUVendor = architectures.GPUVendorNvidia
 		}
@@ -313,7 +316,7 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 
 	loader := &Loader{}
-	loader.Builders = append(loader.Builders, &dns.GossipBuilder{NodeupModelContext: modelContext})
+	loader.Builders = append(loader.Builders, &model.EtcHostsBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.NTPBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.MiscUtilsBuilder{NodeupModelContext: modelContext})
 	loader.Builders = append(loader.Builders, &model.DirectoryBuilder{NodeupModelContext: modelContext})
@@ -363,32 +366,25 @@ func (c *NodeUpCommand) Run(out io.Writer) error {
 	}
 	// Protokube load image task is in ProtokubeBuilder
 
-	var target fi.Target
-	checkExisting := true
+	var target fi.NodeupTarget
 
 	switch c.Target {
 	case "direct":
 		target = &local.LocalTarget{
-			CacheDir:   c.CacheDir,
-			Cloud:      cloud,
-			InstanceID: modelContext.InstanceID,
-			Cluster:    c.cluster,
+			CacheDir: c.CacheDir,
+			Cloud:    cloud,
 		}
 	case "dryrun":
 		assetBuilder := assets.NewAssetBuilder(c.cluster, false)
-		target = fi.NewDryRunTarget(assetBuilder, out)
-	case "cloudinit":
-		checkExisting = false
-		target = cloudinit.NewCloudInitTarget(out)
+		target = fi.NewNodeupDryRunTarget(assetBuilder, out)
 	default:
 		return fmt.Errorf("unsupported target type %q", c.Target)
 	}
 
-	context, err := fi.NewContext(target, c.cluster, cloud, keyStore, secretStore, configBase, checkExisting, taskMap)
+	context, err := fi.NewNodeupContext(ctx, target, keyStore, &bootConfig, &nodeupConfig, taskMap)
 	if err != nil {
 		klog.Exitf("error building context: %v", err)
 	}
-	defer context.Close()
 
 	var options fi.RunTasksOptions
 	options.InitDefaults()
@@ -447,7 +443,7 @@ func completeWarmingLifecycleAction(cloud awsup.AWSCloud, modelContext *model.No
 			AutoScalingGroupName:  &asgName,
 			InstanceId:            &modelContext.InstanceID,
 			LifecycleHookName:     &hookName,
-			LifecycleActionResult: fi.String("CONTINUE"),
+			LifecycleActionResult: fi.PtrTo("CONTINUE"),
 		})
 		if err != nil {
 			return fmt.Errorf("failed to complete lifecycle hook %q for %q: %v", hookName, modelContext.InstanceID, err)
@@ -465,9 +461,6 @@ func evaluateSpec(c *NodeUpCommand, nodeupConfig *nodeup.Config, cloudProvider a
 		return err
 	}
 
-	c.cluster.Spec.Kubelet.HostnameOverride = hostnameOverride
-	c.cluster.Spec.MasterKubelet.HostnameOverride = hostnameOverride
-
 	nodeupConfig.KubeletConfig.HostnameOverride = hostnameOverride
 
 	if c.cluster.Spec.KubeProxy == nil {
@@ -595,8 +588,8 @@ func evaluateBindAddress(bindAddress string) (string, error) {
 
 // evaluateDockerSpec selects the first supported storage mode, if it is a list
 func evaluateDockerSpecStorage(spec *api.DockerConfig) error {
-	storage := fi.StringValue(spec.Storage)
-	if strings.Contains(fi.StringValue(spec.Storage), ",") {
+	storage := fi.ValueOf(spec.Storage)
+	if strings.Contains(fi.ValueOf(spec.Storage), ",") {
 		precedence := strings.Split(storage, ",")
 		for _, opt := range precedence {
 			fs := opt
@@ -626,7 +619,7 @@ func evaluateDockerSpecStorage(spec *api.DockerConfig) error {
 
 			if supported {
 				klog.Infof("Using supported docker storage %q", opt)
-				spec.Storage = fi.String(opt)
+				spec.Storage = fi.PtrTo(opt)
 				return nil
 			}
 
@@ -636,7 +629,7 @@ func evaluateDockerSpecStorage(spec *api.DockerConfig) error {
 		// Just in case we don't recognize the driver?
 		// TODO: Is this the best behaviour
 		klog.Warningf("No storage module was supported from %q, will default to %q", storage, precedence[0])
-		spec.Storage = fi.String(precedence[0])
+		spec.Storage = fi.PtrTo(precedence[0])
 		return nil
 	}
 
@@ -691,7 +684,7 @@ func loadKernelModules(context *model.NodeupModelContext) error {
 
 // getRegion queries the cloud provider for the region.
 func getRegion(ctx context.Context, bootConfig *nodeup.BootConfig) (string, error) {
-	switch api.CloudProviderID(bootConfig.CloudProvider) {
+	switch bootConfig.CloudProvider {
 	case api.CloudProviderAWS:
 		region, err := awsup.RegionFromMetadata(ctx)
 		if err != nil {
@@ -706,7 +699,7 @@ func getRegion(ctx context.Context, bootConfig *nodeup.BootConfig) (string, erro
 
 // seedRNG adds entropy to the random number generator.
 func seedRNG(ctx context.Context, bootConfig *nodeup.BootConfig, region string) error {
-	switch api.CloudProviderID(bootConfig.CloudProvider) {
+	switch bootConfig.CloudProvider {
 	case api.CloudProviderAWS:
 		config := aws.NewConfig().WithCredentialsChainVerboseErrors(true).WithRegion(region)
 		sess, err := session.NewSession(config)
@@ -737,12 +730,12 @@ func seedRNG(ctx context.Context, bootConfig *nodeup.BootConfig, region string)
 	return nil
 }
 
-// getNodeConfigFromServer queries kops-controller for our node's configuration.
-func getNodeConfigFromServer(ctx context.Context, bootConfig *nodeup.BootConfig, region string) (*nodeup.BootstrapResponse, error) {
+// getNodeConfigFromServers queries kops-controllers for our node's configuration.
+func getNodeConfigFromServers(ctx context.Context, bootConfig *nodeup.BootConfig, region string) (*nodeup.BootstrapResponse, error) {
 	var authenticator bootstrap.Authenticator
 	var resolver resolver.Resolver
 
-	switch api.CloudProviderID(bootConfig.CloudProvider) {
+	switch bootConfig.CloudProvider {
 	case api.CloudProviderAWS:
 		a, err := awsup.NewAWSAuthenticator(region)
 		if err != nil {
@@ -761,27 +754,50 @@ func getNodeConfigFromServer(ctx context.Context, bootConfig *nodeup.BootConfig,
 			return nil, err
 		}
 		resolver = discovery
+	case api.CloudProviderHetzner:
+		a, err := hetzner.NewHetznerAuthenticator()
+		if err != nil {
+			return nil, err
+		}
+		authenticator = a
+	case api.CloudProviderOpenstack:
+		a, err := openstack.NewOpenstackAuthenticator()
+		if err != nil {
+			return nil, err
+		}
+		authenticator = a
 	default:
 		return nil, fmt.Errorf("unsupported cloud provider for node configuration %s", bootConfig.CloudProvider)
 	}
 
-	client := &nodetasks.KopsBootstrapClient{
+	client := &kopscontrollerclient.Client{
 		Authenticator: authenticator,
 		Resolver:      resolver,
+		CAs:           []byte(bootConfig.ConfigServer.CACertificates),
 	}
 
-	u, err := url.Parse(bootConfig.ConfigServer.Server)
-	if err != nil {
-		return nil, fmt.Errorf("unable to parse configuration server url %q: %w", bootConfig.ConfigServer.Server, err)
-	}
-	client.BaseURL = *u
-	client.CAs = []byte(bootConfig.ConfigServer.CACertificates)
+	var merr error
+	for _, server := range bootConfig.ConfigServer.Servers {
+		u, err := url.Parse(server)
+		if err != nil {
+			merr = multierr.Append(merr, fmt.Errorf("unable to parse configuration server url %q: %w", server, err))
+			continue
+		}
+		client.BaseURL = *u
 
-	request := nodeup.BootstrapRequest{
-		APIVersion:        nodeup.BootstrapAPIVersion,
-		IncludeNodeConfig: true,
+		request := nodeup.BootstrapRequest{
+			APIVersion:        nodeup.BootstrapAPIVersion,
+			IncludeNodeConfig: true,
+		}
+		var resp nodeup.BootstrapResponse
+		err = client.Query(ctx, &request, &resp)
+		if err != nil {
+			merr = multierr.Append(merr, err)
+			continue
+		}
+		return &resp, nil
 	}
-	return client.QueryBootstrap(ctx, &request)
+	return nil, merr
 }
 
 func getAWSConfigurationMode(c *model.NodeupModelContext) (string, error) {
@@ -804,7 +820,7 @@ func getAWSConfigurationMode(c *model.NodeupModelContext) (string, error) {
 	if len(result.AutoScalingInstances) < 1 {
 		return "", nil
 	}
-	lifecycle := fi.StringValue(result.AutoScalingInstances[0].LifecycleState)
+	lifecycle := fi.ValueOf(result.AutoScalingInstances[0].LifecycleState)
 	if strings.HasPrefix(lifecycle, "Warmed:") {
 		klog.Info("instance is entering warm pool")
 		return model.ConfigurationModeWarming, nil
