@@ -37,7 +37,7 @@ func (m EnvVars) addEnvVariableIfExist(name string) {
 func BuildSystemComponentEnvVars(spec *kops.ClusterSpec) EnvVars {
 	vars := make(EnvVars)
 
-	for _, v := range proxy.GetProxyEnvVars(spec.EgressProxy) {
+	for _, v := range proxy.GetProxyEnvVars(spec.Networking.EgressProxy) {
 		vars[v.Name] = v.Value
 	}
 
@@ -72,6 +72,13 @@ func BuildSystemComponentEnvVars(spec *kops.ClusterSpec) EnvVars {
 	// Azure related values.
 	vars.addEnvVariableIfExist("AZURE_STORAGE_ACCOUNT")
 
+	// Scaleway related values.
+	vars.addEnvVariableIfExist("SCW_ACCESS_KEY")
+	vars.addEnvVariableIfExist("SCW_SECRET_KEY")
+	vars.addEnvVariableIfExist("SCW_DEFAULT_PROJECT_ID")
+	vars.addEnvVariableIfExist("SCW_DEFAULT_REGION")
+	vars.addEnvVariableIfExist("SCW_DEFAULT_ZONE")
+
 	return vars
 }
 
